// Code generated by smithy-go-codegen DO NOT EDIT.

package schemas

import (
	smithy "github.com/aws/smithy-go"
	smithyprelude "github.com/aws/smithy-go/prelude"
	smithytraits "github.com/aws/smithy-go/traits"
)

var AllQueryStringTypes = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "AllQueryStringTypes",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/AllQueryStringTypesInput",
	Code: 200})

var BodyWithXmlName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "BodyWithXmlName",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/BodyWithXmlName",
	Code: 200})

var ConstantAndVariableQueryString = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "ConstantAndVariableQueryString",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/ConstantAndVariableQueryString?foo=bar",
	Code: 200})

var ConstantQueryString = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "ConstantQueryString",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/ConstantQueryString/{hello}?foo=bar&hello",
	Code: 200})

var ContentTypeParameters = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "ContentTypeParameters",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/ContentTypeParameters",
	Code: 200})

var DatetimeOffsets = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "DatetimeOffsets",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/DatetimeOffsets",
	Code: 200})

var EmptyInputAndEmptyOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "EmptyInputAndEmptyOutput",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/EmptyInputAndEmptyOutput",
	Code: 200})

var EndpointOperation = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "EndpointOperation",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/EndpointOperation",
	Code: 200})

var EndpointWithHostLabelHeaderOperation = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "EndpointWithHostLabelHeaderOperation",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/EndpointWithHostLabelHeaderOperation",
	Code: 200})

var EndpointWithHostLabelOperation = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "EndpointWithHostLabelOperation",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/EndpointWithHostLabelOperation",
	Code: 200})

var FlattenedXmlMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "FlattenedXmlMap",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/FlattenedXmlMap",
	Code: 200})

var FlattenedXmlMapWithXmlName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "FlattenedXmlMapWithXmlName",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/FlattenedXmlMapWithXmlName",
	Code: 200})

var FlattenedXmlMapWithXmlNamespace = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "FlattenedXmlMapWithXmlNamespace",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/FlattenedXmlMapWithXmlNamespace",
	Code: 200})

var FractionalSeconds = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "FractionalSeconds",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/FractionalSeconds",
	Code: 200})

var GreetingWithErrors = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "GreetingWithErrors",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/GreetingWithErrors",
	Code: 200})

var HttpEmptyPrefixHeaders = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpEmptyPrefixHeaders",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/HttpEmptyPrefixHeaders",
	Code: 200})

var HttpEnumPayload = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpEnumPayload",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/EnumPayload",
	Code: 200})

var HttpPayloadTraits = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpPayloadTraits",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/HttpPayloadTraits",
	Code: 200})

var HttpPayloadTraitsWithMediaType = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpPayloadTraitsWithMediaType",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/HttpPayloadTraitsWithMediaType",
	Code: 200})

var HttpPayloadWithMemberXmlName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpPayloadWithMemberXmlName",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/HttpPayloadWithMemberXmlName",
	Code: 200})

var HttpPayloadWithStructure = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpPayloadWithStructure",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/HttpPayloadWithStructure",
	Code: 200})

var HttpPayloadWithUnion = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpPayloadWithUnion",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/HttpPayloadWithUnion",
	Code: 200})

var HttpPayloadWithXmlName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpPayloadWithXmlName",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/HttpPayloadWithXmlName",
	Code: 200})

var HttpPayloadWithXmlNamespace = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpPayloadWithXmlNamespace",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/HttpPayloadWithXmlNamespace",
	Code: 200})

var HttpPayloadWithXmlNamespaceAndPrefix = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpPayloadWithXmlNamespaceAndPrefix",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/HttpPayloadWithXmlNamespaceAndPrefix",
	Code: 200})

var HttpPrefixHeaders = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpPrefixHeaders",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/HttpPrefixHeaders",
	Code: 200})

var HttpRequestWithFloatLabels = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpRequestWithFloatLabels",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/FloatHttpLabels/{float}/{double}",
	Code: 200})

var HttpRequestWithGreedyLabelInPath = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpRequestWithGreedyLabelInPath",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/HttpRequestWithGreedyLabelInPath/foo/{foo}/baz/{baz+}",
	Code: 200})

var HttpRequestWithLabels = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpRequestWithLabels",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/HttpRequestWithLabels/{string}/{short}/{integer}/{long}/{float}/{double}/{boolean}/{timestamp}",
	Code: 200})

var HttpRequestWithLabelsAndTimestampFormat = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpRequestWithLabelsAndTimestampFormat",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/HttpRequestWithLabelsAndTimestampFormat/{memberEpochSeconds}/{memberHttpDate}/{memberDateTime}/{defaultFormat}/{targetEpochSeconds}/{targetHttpDate}/{targetDateTime}",
	Code: 200})

var HttpResponseCode = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpResponseCode",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/HttpResponseCode",
	Code: 200})

var HttpStringPayload = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpStringPayload",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/StringPayload",
	Code: 200})

var IgnoreQueryParamsInResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "IgnoreQueryParamsInResponse",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/IgnoreQueryParamsInResponse",
	Code: 200})

var InputAndOutputWithHeaders = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "InputAndOutputWithHeaders",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/InputAndOutputWithHeaders",
	Code: 200})

var NestedXmlMaps = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "NestedXmlMaps",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/NestedXmlMaps",
	Code: 200})

var NestedXmlMapWithXmlName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "NestedXmlMapWithXmlName",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/NestedXmlMapWithXmlName",
	Code: 200})

var NoInputAndNoOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "NoInputAndNoOutput",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/NoInputAndNoOutput",
	Code: 200})

var NoInputAndOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "NoInputAndOutput",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/NoInputAndOutputOutput",
	Code: 200})

var NullAndEmptyHeadersClient = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "NullAndEmptyHeadersClient",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/NullAndEmptyHeadersClient",
	Code: 200})

var NullAndEmptyHeadersServer = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "NullAndEmptyHeadersServer",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/NullAndEmptyHeadersServer",
	Code: 200})

var OmitsNullSerializesEmptyString = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "OmitsNullSerializesEmptyString",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/OmitsNullSerializesEmptyString",
	Code: 200})

var PutWithContentEncoding = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "PutWithContentEncoding",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/requestcompression/putcontentwithencoding",
	Code: 200})

var QueryIdempotencyTokenAutoFill = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "QueryIdempotencyTokenAutoFill",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/QueryIdempotencyTokenAutoFill",
	Code: 200})

var QueryParamsAsStringListMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "QueryParamsAsStringListMap",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/StringListMap",
	Code: 200})

var QueryPrecedence = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "QueryPrecedence",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/Precedence",
	Code: 200})

var RecursiveShapes = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "RecursiveShapes",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/RecursiveShapes",
	Code: 200})

var SimpleScalarProperties = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "SimpleScalarProperties",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/SimpleScalarProperties",
	Code: 200})

var TimestampFormatHeaders = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "TimestampFormatHeaders",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/TimestampFormatHeaders",
	Code: 200})

var XmlAttributes = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlAttributes",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/XmlAttributes",
	Code: 200})

var XmlAttributesInMiddle = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlAttributesInMiddle",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/XmlAttributesInMiddle",
	Code: 200})

var XmlAttributesOnPayload = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlAttributesOnPayload",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/XmlAttributesOnPayload",
	Code: 200})

var XmlBlobs = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlBlobs",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/XmlBlobs",
	Code: 200})

var XmlEmptyBlobs = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlEmptyBlobs",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/XmlEmptyBlobs",
	Code: 200})

var XmlEmptyLists = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlEmptyLists",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/XmlEmptyLists",
	Code: 200})

var XmlEmptyMaps = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlEmptyMaps",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/XmlEmptyMaps",
	Code: 200})

var XmlEmptyStrings = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlEmptyStrings",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/XmlEmptyStrings",
	Code: 200})

var XmlEnums = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlEnums",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/XmlEnums",
	Code: 200})

var XmlIntEnums = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlIntEnums",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/XmlIntEnums",
	Code: 200})

var XmlLists = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlLists",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/XmlLists",
	Code: 200})

var XmlMaps = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlMaps",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/XmlMaps",
	Code: 200})

var XmlMapsXmlName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlMapsXmlName",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/XmlMapsXmlName",
	Code: 200})

var XmlMapWithXmlNamespace = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlMapWithXmlNamespace",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/XmlMapWithXmlNamespace",
	Code: 200})

var XmlNamespaces = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlNamespaces",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/XmlNamespaces",
	Code: 200})

var XmlTimestamps = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlTimestamps",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/XmlTimestamps",
	Code: 200})

var XmlUnions = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlUnions",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/XmlUnions",
	Code: 200})

var _RestXml = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "RestXml",
}, smithy.ShapeTypeService, 0)

var RestXml = smithy.NewServiceSchema(_RestXml, "2019-12-16")

var ComplexError = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "ComplexError",
}, smithy.ShapeTypeStructure, 3, &smithytraits.HTTPError{Code: 403})
var ComplexError_Header *smithy.Schema

var ComplexError_TopLevel *smithy.Schema

var ComplexError_Nested *smithy.Schema

var ComplexNestedErrorData = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "ComplexNestedErrorData",
}, smithy.ShapeTypeStructure, 1)
var ComplexNestedErrorData_Foo *smithy.Schema

var _FlattenedXmlMapWithXmlNameInputOutputMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "FlattenedXmlMapWithXmlNameInputOutputMap",
}, smithy.ShapeTypeMap, 2)
var _FlattenedXmlMapWithXmlNameInputOutputMap_key *smithy.Schema

var _FlattenedXmlMapWithXmlNameInputOutputMap_value *smithy.Schema

var _FlattenedXmlMapWithXmlNamespaceOutputMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "FlattenedXmlMapWithXmlNamespaceOutputMap",
}, smithy.ShapeTypeMap, 2)
var _FlattenedXmlMapWithXmlNamespaceOutputMap_key *smithy.Schema

var _FlattenedXmlMapWithXmlNamespaceOutputMap_value *smithy.Schema

var _FooPrefixHeaders = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "FooPrefixHeaders",
}, smithy.ShapeTypeMap, 2)
var _FooPrefixHeaders_key *smithy.Schema

var _FooPrefixHeaders_value *smithy.Schema

var InvalidGreeting = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "InvalidGreeting",
}, smithy.ShapeTypeStructure, 1, &smithytraits.HTTPError{Code: 400})
var InvalidGreeting_Message *smithy.Schema

var _ListWithMemberNamespace = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "ListWithMemberNamespace",
}, smithy.ShapeTypeList, 1, &smithytraits.XMLNamespace{URI: "https://xml-list.example.com"})
var _ListWithMemberNamespace_member *smithy.Schema

var _ListWithNamespace = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "ListWithNamespace",
}, smithy.ShapeTypeList, 1, &smithytraits.XMLNamespace{URI: "https://xml-list.example.com"})
var _ListWithNamespace_member *smithy.Schema

var _NestedMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "NestedMap",
}, smithy.ShapeTypeMap, 2)
var _NestedMap_key *smithy.Schema

var _NestedMap_value *smithy.Schema

var NestedPayload = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "NestedPayload",
}, smithy.ShapeTypeStructure, 2)
var NestedPayload_greeting *smithy.Schema

var NestedPayload_name *smithy.Schema

var _NestedXmlMapWithXmlNameInnerMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "NestedXmlMapWithXmlNameInnerMap",
}, smithy.ShapeTypeMap, 2)
var _NestedXmlMapWithXmlNameInnerMap_key *smithy.Schema

var _NestedXmlMapWithXmlNameInnerMap_value *smithy.Schema

var _NestedXmlMapWithXmlNameMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "NestedXmlMapWithXmlNameMap",
}, smithy.ShapeTypeMap, 2)
var _NestedXmlMapWithXmlNameMap_key *smithy.Schema

var _NestedXmlMapWithXmlNameMap_value *smithy.Schema

var PayloadWithXmlName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "PayloadWithXmlName",
}, smithy.ShapeTypeStructure, 1, &smithytraits.XMLName{Name: "Hello"})
var PayloadWithXmlName_name *smithy.Schema

var PayloadWithXmlNamespace = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "PayloadWithXmlNamespace",
}, smithy.ShapeTypeStructure, 1, &smithytraits.XMLNamespace{URI: "http://foo.com"})
var PayloadWithXmlNamespace_name *smithy.Schema

var PayloadWithXmlNamespaceAndPrefix = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "PayloadWithXmlNamespaceAndPrefix",
}, smithy.ShapeTypeStructure, 1, &smithytraits.XMLNamespace{URI: "http://foo.com",
	Prefix: "baz"})
var PayloadWithXmlNamespaceAndPrefix_name *smithy.Schema

var RecursiveShapesInputOutputNested1 = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "RecursiveShapesInputOutputNested1",
}, smithy.ShapeTypeStructure, 2)
var RecursiveShapesInputOutputNested1_foo *smithy.Schema

var RecursiveShapesInputOutputNested1_nested *smithy.Schema

var RecursiveShapesInputOutputNested2 = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "RecursiveShapesInputOutputNested2",
}, smithy.ShapeTypeStructure, 2)
var RecursiveShapesInputOutputNested2_bar *smithy.Schema

var RecursiveShapesInputOutputNested2_recursiveMember *smithy.Schema

var _RenamedListMembers = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "RenamedListMembers",
}, smithy.ShapeTypeList, 1)
var _RenamedListMembers_member *smithy.Schema

var StringEnum = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "StringEnum",
}, smithy.ShapeTypeEnum, 1)
var StringEnum_V *smithy.Schema

var _StructureList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "StructureList",
}, smithy.ShapeTypeList, 1)
var _StructureList_member *smithy.Schema

var StructureListMember = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "StructureListMember",
}, smithy.ShapeTypeStructure, 2)
var StructureListMember_a *smithy.Schema

var StructureListMember_b *smithy.Schema

var UnionPayload = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "UnionPayload",
}, smithy.ShapeTypeUnion, 1)
var UnionPayload_greeting *smithy.Schema

var XmlAttributesInMiddlePayloadRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlAttributesInMiddlePayloadRequest",
}, smithy.ShapeTypeStructure, 3)
var XmlAttributesInMiddlePayloadRequest_foo *smithy.Schema

var XmlAttributesInMiddlePayloadRequest_attr *smithy.Schema

var XmlAttributesInMiddlePayloadRequest_baz *smithy.Schema

var XmlAttributesInMiddlePayloadResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlAttributesInMiddlePayloadResponse",
}, smithy.ShapeTypeStructure, 3)
var XmlAttributesInMiddlePayloadResponse_foo *smithy.Schema

var XmlAttributesInMiddlePayloadResponse_attr *smithy.Schema

var XmlAttributesInMiddlePayloadResponse_baz *smithy.Schema

var XmlAttributesPayloadRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlAttributesPayloadRequest",
}, smithy.ShapeTypeStructure, 2)
var XmlAttributesPayloadRequest_foo *smithy.Schema

var XmlAttributesPayloadRequest_attr *smithy.Schema

var XmlAttributesPayloadResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlAttributesPayloadResponse",
}, smithy.ShapeTypeStructure, 2)
var XmlAttributesPayloadResponse_foo *smithy.Schema

var XmlAttributesPayloadResponse_attr *smithy.Schema

var _XmlMapsInputOutputMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlMapsInputOutputMap",
}, smithy.ShapeTypeMap, 2)
var _XmlMapsInputOutputMap_key *smithy.Schema

var _XmlMapsInputOutputMap_value *smithy.Schema

var _XmlMapsXmlNameInputOutputMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlMapsXmlNameInputOutputMap",
}, smithy.ShapeTypeMap, 2)
var _XmlMapsXmlNameInputOutputMap_key *smithy.Schema

var _XmlMapsXmlNameInputOutputMap_value *smithy.Schema

var _XmlMapWithXmlNamespaceInputOutputMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlMapWithXmlNamespaceInputOutputMap",
}, smithy.ShapeTypeMap, 2)
var _XmlMapWithXmlNamespaceInputOutputMap_key *smithy.Schema

var _XmlMapWithXmlNamespaceInputOutputMap_value *smithy.Schema

var _XmlNamespacedList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlNamespacedList",
}, smithy.ShapeTypeList, 1)
var _XmlNamespacedList_member *smithy.Schema

var XmlNamespaceNested = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlNamespaceNested",
}, smithy.ShapeTypeStructure, 2, &smithytraits.XMLNamespace{URI: "http://foo.com"})
var XmlNamespaceNested_foo *smithy.Schema

var XmlNamespaceNested_values *smithy.Schema

var XmlNestedUnionStruct = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlNestedUnionStruct",
}, smithy.ShapeTypeStructure, 8)
var XmlNestedUnionStruct_stringValue *smithy.Schema

var XmlNestedUnionStruct_booleanValue *smithy.Schema

var XmlNestedUnionStruct_byteValue *smithy.Schema

var XmlNestedUnionStruct_shortValue *smithy.Schema

var XmlNestedUnionStruct_integerValue *smithy.Schema

var XmlNestedUnionStruct_longValue *smithy.Schema

var XmlNestedUnionStruct_floatValue *smithy.Schema

var XmlNestedUnionStruct_doubleValue *smithy.Schema

var XmlUnionShape = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlUnionShape",
}, smithy.ShapeTypeUnion, 10)
var XmlUnionShape_stringValue *smithy.Schema

var XmlUnionShape_booleanValue *smithy.Schema

var XmlUnionShape_byteValue *smithy.Schema

var XmlUnionShape_shortValue *smithy.Schema

var XmlUnionShape_integerValue *smithy.Schema

var XmlUnionShape_longValue *smithy.Schema

var XmlUnionShape_floatValue *smithy.Schema

var XmlUnionShape_doubleValue *smithy.Schema

var XmlUnionShape_unionValue *smithy.Schema

var XmlUnionShape_structValue *smithy.Schema

var _BooleanList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "BooleanList",
}, smithy.ShapeTypeList, 1)
var _BooleanList_member *smithy.Schema

var _DateTime = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "DateTime",
}, smithy.ShapeTypeTimestamp, 0, &smithytraits.TimestampFormat{Format: "date-time"})

var _DoubleList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "DoubleList",
}, smithy.ShapeTypeList, 1)
var _DoubleList_member *smithy.Schema

var _EpochSeconds = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "EpochSeconds",
}, smithy.ShapeTypeTimestamp, 0, &smithytraits.TimestampFormat{Format: "epoch-seconds"})

var FooEnum = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "FooEnum",
}, smithy.ShapeTypeEnum, 5)
var FooEnum_FOO *smithy.Schema

var FooEnum_BAZ *smithy.Schema

var FooEnum_BAR *smithy.Schema

var FooEnum_ONE *smithy.Schema

var FooEnum_ZERO *smithy.Schema

var _FooEnumList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "FooEnumList",
}, smithy.ShapeTypeList, 1)
var _FooEnumList_member *smithy.Schema

var _FooEnumMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "FooEnumMap",
}, smithy.ShapeTypeMap, 2)
var _FooEnumMap_key *smithy.Schema

var _FooEnumMap_value *smithy.Schema

var _FooEnumSet = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "FooEnumSet",
}, smithy.ShapeTypeList, 1)
var _FooEnumSet_member *smithy.Schema

var GreetingStruct = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "GreetingStruct",
}, smithy.ShapeTypeStructure, 1)
var GreetingStruct_hi *smithy.Schema

var _HttpDate = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "HttpDate",
}, smithy.ShapeTypeTimestamp, 0, &smithytraits.TimestampFormat{Format: "http-date"})

var _IntegerEnum = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "IntegerEnum",
}, smithy.ShapeTypeIntEnum, 3)
var _IntegerEnum_A *smithy.Schema

var _IntegerEnum_B *smithy.Schema

var _IntegerEnum_C *smithy.Schema

var _IntegerEnumList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "IntegerEnumList",
}, smithy.ShapeTypeList, 1)
var _IntegerEnumList_member *smithy.Schema

var _IntegerEnumMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "IntegerEnumMap",
}, smithy.ShapeTypeMap, 2)
var _IntegerEnumMap_key *smithy.Schema

var _IntegerEnumMap_value *smithy.Schema

var _IntegerEnumSet = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "IntegerEnumSet",
}, smithy.ShapeTypeList, 1)
var _IntegerEnumSet_member *smithy.Schema

var _IntegerList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "IntegerList",
}, smithy.ShapeTypeList, 1)
var _IntegerList_member *smithy.Schema

var _IntegerSet = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "IntegerSet",
}, smithy.ShapeTypeList, 1)
var _IntegerSet_member *smithy.Schema

var _NestedStringList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "NestedStringList",
}, smithy.ShapeTypeList, 1)
var _NestedStringList_member *smithy.Schema

var _StringList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "StringList",
}, smithy.ShapeTypeList, 1)
var _StringList_member *smithy.Schema

var _StringListMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "StringListMap",
}, smithy.ShapeTypeMap, 2)
var _StringListMap_key *smithy.Schema

var _StringListMap_value *smithy.Schema

var _StringMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "StringMap",
}, smithy.ShapeTypeMap, 2)
var _StringMap_key *smithy.Schema

var _StringMap_value *smithy.Schema

var _StringSet = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "StringSet",
}, smithy.ShapeTypeList, 1)
var _StringSet_member *smithy.Schema

var _TextPlainBlob = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "TextPlainBlob",
}, smithy.ShapeTypeBlob, 0, &smithytraits.MediaType{Type: "text/plain"})

var _TimestampList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "TimestampList",
}, smithy.ShapeTypeList, 1)
var _TimestampList_member *smithy.Schema

var AllQueryStringTypesInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "AllQueryStringTypesInput",
}, smithy.ShapeTypeStructure, 21)
var AllQueryStringTypesInput_queryString *smithy.Schema

var AllQueryStringTypesInput_queryStringList *smithy.Schema

var AllQueryStringTypesInput_queryStringSet *smithy.Schema

var AllQueryStringTypesInput_queryByte *smithy.Schema

var AllQueryStringTypesInput_queryShort *smithy.Schema

var AllQueryStringTypesInput_queryInteger *smithy.Schema

var AllQueryStringTypesInput_queryIntegerList *smithy.Schema

var AllQueryStringTypesInput_queryIntegerSet *smithy.Schema

var AllQueryStringTypesInput_queryLong *smithy.Schema

var AllQueryStringTypesInput_queryFloat *smithy.Schema

var AllQueryStringTypesInput_queryDouble *smithy.Schema

var AllQueryStringTypesInput_queryDoubleList *smithy.Schema

var AllQueryStringTypesInput_queryBoolean *smithy.Schema

var AllQueryStringTypesInput_queryBooleanList *smithy.Schema

var AllQueryStringTypesInput_queryTimestamp *smithy.Schema

var AllQueryStringTypesInput_queryTimestampList *smithy.Schema

var AllQueryStringTypesInput_queryEnum *smithy.Schema

var AllQueryStringTypesInput_queryEnumList *smithy.Schema

var AllQueryStringTypesInput_queryIntegerEnum *smithy.Schema

var AllQueryStringTypesInput_queryIntegerEnumList *smithy.Schema

var AllQueryStringTypesInput_queryParamsMapOfStrings *smithy.Schema

var BodyWithXmlNameInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "BodyWithXmlNameInputOutput",
}, smithy.ShapeTypeStructure, 1, &smithytraits.XMLName{Name: "Ahoy"})
var BodyWithXmlNameInputOutput_nested *smithy.Schema

var ConstantAndVariableQueryStringInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "ConstantAndVariableQueryStringInput",
}, smithy.ShapeTypeStructure, 2)
var ConstantAndVariableQueryStringInput_baz *smithy.Schema

var ConstantAndVariableQueryStringInput_maybeSet *smithy.Schema

var ConstantQueryStringInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "ConstantQueryStringInput",
}, smithy.ShapeTypeStructure, 1)
var ConstantQueryStringInput_hello *smithy.Schema

var ContentTypeParametersInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "ContentTypeParametersInput",
}, smithy.ShapeTypeStructure, 1)
var ContentTypeParametersInput_value *smithy.Schema

var ContentTypeParametersOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "ContentTypeParametersOutput",
}, smithy.ShapeTypeStructure, 0)

var DatetimeOffsetsOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "DatetimeOffsetsOutput",
}, smithy.ShapeTypeStructure, 1)
var DatetimeOffsetsOutput_datetime *smithy.Schema

var EmptyInputAndEmptyOutputInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "EmptyInputAndEmptyOutputInput",
}, smithy.ShapeTypeStructure, 0)

var EmptyInputAndEmptyOutputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "EmptyInputAndEmptyOutputOutput",
}, smithy.ShapeTypeStructure, 0)

var HostLabelHeaderInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HostLabelHeaderInput",
}, smithy.ShapeTypeStructure, 1)
var HostLabelHeaderInput_accountId *smithy.Schema

var EndpointWithHostLabelOperationRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "EndpointWithHostLabelOperationRequest",
}, smithy.ShapeTypeStructure, 1)
var EndpointWithHostLabelOperationRequest_label *smithy.Schema

var FlattenedXmlMapRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "FlattenedXmlMapRequest",
}, smithy.ShapeTypeStructure, 1)
var FlattenedXmlMapRequest_myMap *smithy.Schema

var FlattenedXmlMapResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "FlattenedXmlMapResponse",
}, smithy.ShapeTypeStructure, 1)
var FlattenedXmlMapResponse_myMap *smithy.Schema

var FlattenedXmlMapWithXmlNameRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "FlattenedXmlMapWithXmlNameRequest",
}, smithy.ShapeTypeStructure, 1)
var FlattenedXmlMapWithXmlNameRequest_myMap *smithy.Schema

var FlattenedXmlMapWithXmlNameResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "FlattenedXmlMapWithXmlNameResponse",
}, smithy.ShapeTypeStructure, 1)
var FlattenedXmlMapWithXmlNameResponse_myMap *smithy.Schema

var FlattenedXmlMapWithXmlNamespaceOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "FlattenedXmlMapWithXmlNamespaceOutput",
}, smithy.ShapeTypeStructure, 1)
var FlattenedXmlMapWithXmlNamespaceOutput_myMap *smithy.Schema

var FractionalSecondsOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "FractionalSecondsOutput",
}, smithy.ShapeTypeStructure, 1)
var FractionalSecondsOutput_datetime *smithy.Schema

var GreetingWithErrorsOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "GreetingWithErrorsOutput",
}, smithy.ShapeTypeStructure, 1)
var GreetingWithErrorsOutput_greeting *smithy.Schema

var HttpEmptyPrefixHeadersInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpEmptyPrefixHeadersInput",
}, smithy.ShapeTypeStructure, 2)
var HttpEmptyPrefixHeadersInput_prefixHeaders *smithy.Schema

var HttpEmptyPrefixHeadersInput_specificHeader *smithy.Schema

var HttpEmptyPrefixHeadersOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpEmptyPrefixHeadersOutput",
}, smithy.ShapeTypeStructure, 2)
var HttpEmptyPrefixHeadersOutput_prefixHeaders *smithy.Schema

var HttpEmptyPrefixHeadersOutput_specificHeader *smithy.Schema

var EnumPayloadInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "EnumPayloadInput",
}, smithy.ShapeTypeStructure, 1)
var EnumPayloadInput_payload *smithy.Schema

var HttpPayloadTraitsInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpPayloadTraitsInputOutput",
}, smithy.ShapeTypeStructure, 2)
var HttpPayloadTraitsInputOutput_foo *smithy.Schema

var HttpPayloadTraitsInputOutput_blob *smithy.Schema

var HttpPayloadTraitsWithMediaTypeInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpPayloadTraitsWithMediaTypeInputOutput",
}, smithy.ShapeTypeStructure, 2)
var HttpPayloadTraitsWithMediaTypeInputOutput_foo *smithy.Schema

var HttpPayloadTraitsWithMediaTypeInputOutput_blob *smithy.Schema

var HttpPayloadWithMemberXmlNameInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpPayloadWithMemberXmlNameInputOutput",
}, smithy.ShapeTypeStructure, 1)
var HttpPayloadWithMemberXmlNameInputOutput_nested *smithy.Schema

var HttpPayloadWithStructureInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpPayloadWithStructureInputOutput",
}, smithy.ShapeTypeStructure, 1)
var HttpPayloadWithStructureInputOutput_nested *smithy.Schema

var HttpPayloadWithUnionInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpPayloadWithUnionInputOutput",
}, smithy.ShapeTypeStructure, 1)
var HttpPayloadWithUnionInputOutput_nested *smithy.Schema

var HttpPayloadWithXmlNameInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpPayloadWithXmlNameInputOutput",
}, smithy.ShapeTypeStructure, 1)
var HttpPayloadWithXmlNameInputOutput_nested *smithy.Schema

var HttpPayloadWithXmlNamespaceAndPrefixInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpPayloadWithXmlNamespaceAndPrefixInputOutput",
}, smithy.ShapeTypeStructure, 1)
var HttpPayloadWithXmlNamespaceAndPrefixInputOutput_nested *smithy.Schema

var HttpPayloadWithXmlNamespaceInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpPayloadWithXmlNamespaceInputOutput",
}, smithy.ShapeTypeStructure, 1)
var HttpPayloadWithXmlNamespaceInputOutput_nested *smithy.Schema

var HttpPrefixHeadersInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpPrefixHeadersInputOutput",
}, smithy.ShapeTypeStructure, 2)
var HttpPrefixHeadersInputOutput_foo *smithy.Schema

var HttpPrefixHeadersInputOutput_fooMap *smithy.Schema

var HttpRequestWithFloatLabelsInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpRequestWithFloatLabelsInput",
}, smithy.ShapeTypeStructure, 2)
var HttpRequestWithFloatLabelsInput_float *smithy.Schema

var HttpRequestWithFloatLabelsInput_double *smithy.Schema

var HttpRequestWithGreedyLabelInPathInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpRequestWithGreedyLabelInPathInput",
}, smithy.ShapeTypeStructure, 2)
var HttpRequestWithGreedyLabelInPathInput_foo *smithy.Schema

var HttpRequestWithGreedyLabelInPathInput_baz *smithy.Schema

var HttpRequestWithLabelsAndTimestampFormatInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpRequestWithLabelsAndTimestampFormatInput",
}, smithy.ShapeTypeStructure, 7)
var HttpRequestWithLabelsAndTimestampFormatInput_memberEpochSeconds *smithy.Schema

var HttpRequestWithLabelsAndTimestampFormatInput_memberHttpDate *smithy.Schema

var HttpRequestWithLabelsAndTimestampFormatInput_memberDateTime *smithy.Schema

var HttpRequestWithLabelsAndTimestampFormatInput_defaultFormat *smithy.Schema

var HttpRequestWithLabelsAndTimestampFormatInput_targetEpochSeconds *smithy.Schema

var HttpRequestWithLabelsAndTimestampFormatInput_targetHttpDate *smithy.Schema

var HttpRequestWithLabelsAndTimestampFormatInput_targetDateTime *smithy.Schema

var HttpRequestWithLabelsInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpRequestWithLabelsInput",
}, smithy.ShapeTypeStructure, 8)
var HttpRequestWithLabelsInput_string *smithy.Schema

var HttpRequestWithLabelsInput_short *smithy.Schema

var HttpRequestWithLabelsInput_integer *smithy.Schema

var HttpRequestWithLabelsInput_long *smithy.Schema

var HttpRequestWithLabelsInput_float *smithy.Schema

var HttpRequestWithLabelsInput_double *smithy.Schema

var HttpRequestWithLabelsInput_boolean *smithy.Schema

var HttpRequestWithLabelsInput_timestamp *smithy.Schema

var HttpResponseCodeOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "HttpResponseCodeOutput",
}, smithy.ShapeTypeStructure, 1)
var HttpResponseCodeOutput_Status *smithy.Schema

var StringPayloadInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "StringPayloadInput",
}, smithy.ShapeTypeStructure, 1)
var StringPayloadInput_payload *smithy.Schema

var IgnoreQueryParamsInResponseOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "IgnoreQueryParamsInResponseOutput",
}, smithy.ShapeTypeStructure, 1)
var IgnoreQueryParamsInResponseOutput_baz *smithy.Schema

var InputAndOutputWithHeadersIO = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "InputAndOutputWithHeadersIO",
}, smithy.ShapeTypeStructure, 16)
var InputAndOutputWithHeadersIO_headerString *smithy.Schema

var InputAndOutputWithHeadersIO_headerByte *smithy.Schema

var InputAndOutputWithHeadersIO_headerShort *smithy.Schema

var InputAndOutputWithHeadersIO_headerInteger *smithy.Schema

var InputAndOutputWithHeadersIO_headerLong *smithy.Schema

var InputAndOutputWithHeadersIO_headerFloat *smithy.Schema

var InputAndOutputWithHeadersIO_headerDouble *smithy.Schema

var InputAndOutputWithHeadersIO_headerTrueBool *smithy.Schema

var InputAndOutputWithHeadersIO_headerFalseBool *smithy.Schema

var InputAndOutputWithHeadersIO_headerStringList *smithy.Schema

var InputAndOutputWithHeadersIO_headerStringSet *smithy.Schema

var InputAndOutputWithHeadersIO_headerIntegerList *smithy.Schema

var InputAndOutputWithHeadersIO_headerBooleanList *smithy.Schema

var InputAndOutputWithHeadersIO_headerTimestampList *smithy.Schema

var InputAndOutputWithHeadersIO_headerEnum *smithy.Schema

var InputAndOutputWithHeadersIO_headerEnumList *smithy.Schema

var NestedXmlMapsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "NestedXmlMapsRequest",
}, smithy.ShapeTypeStructure, 2)
var NestedXmlMapsRequest_nestedMap *smithy.Schema

var NestedXmlMapsRequest_flatNestedMap *smithy.Schema

var NestedXmlMapsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "NestedXmlMapsResponse",
}, smithy.ShapeTypeStructure, 2)
var NestedXmlMapsResponse_nestedMap *smithy.Schema

var NestedXmlMapsResponse_flatNestedMap *smithy.Schema

var NestedXmlMapWithXmlNameRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "NestedXmlMapWithXmlNameRequest",
}, smithy.ShapeTypeStructure, 1)
var NestedXmlMapWithXmlNameRequest_nestedXmlMapWithXmlNameMap *smithy.Schema

var NestedXmlMapWithXmlNameResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "NestedXmlMapWithXmlNameResponse",
}, smithy.ShapeTypeStructure, 1)
var NestedXmlMapWithXmlNameResponse_nestedXmlMapWithXmlNameMap *smithy.Schema

var NoInputAndOutputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "NoInputAndOutputOutput",
}, smithy.ShapeTypeStructure, 0)

var NullAndEmptyHeadersIO = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "NullAndEmptyHeadersIO",
}, smithy.ShapeTypeStructure, 3)
var NullAndEmptyHeadersIO_a *smithy.Schema

var NullAndEmptyHeadersIO_b *smithy.Schema

var NullAndEmptyHeadersIO_c *smithy.Schema

var OmitsNullSerializesEmptyStringInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "OmitsNullSerializesEmptyStringInput",
}, smithy.ShapeTypeStructure, 2)
var OmitsNullSerializesEmptyStringInput_nullValue *smithy.Schema

var OmitsNullSerializesEmptyStringInput_emptyString *smithy.Schema

var PutWithContentEncodingInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "PutWithContentEncodingInput",
}, smithy.ShapeTypeStructure, 2)
var PutWithContentEncodingInput_encoding *smithy.Schema

var PutWithContentEncodingInput_data *smithy.Schema

var QueryIdempotencyTokenAutoFillInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "QueryIdempotencyTokenAutoFillInput",
}, smithy.ShapeTypeStructure, 1)
var QueryIdempotencyTokenAutoFillInput_token *smithy.Schema

var QueryParamsAsStringListMapInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "QueryParamsAsStringListMapInput",
}, smithy.ShapeTypeStructure, 2)
var QueryParamsAsStringListMapInput_qux *smithy.Schema

var QueryParamsAsStringListMapInput_foo *smithy.Schema

var QueryPrecedenceInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "QueryPrecedenceInput",
}, smithy.ShapeTypeStructure, 2)
var QueryPrecedenceInput_foo *smithy.Schema

var QueryPrecedenceInput_baz *smithy.Schema

var RecursiveShapesRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "RecursiveShapesRequest",
}, smithy.ShapeTypeStructure, 1)
var RecursiveShapesRequest_nested *smithy.Schema

var RecursiveShapesResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "RecursiveShapesResponse",
}, smithy.ShapeTypeStructure, 1)
var RecursiveShapesResponse_nested *smithy.Schema

var SimpleScalarPropertiesRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "SimpleScalarPropertiesRequest",
}, smithy.ShapeTypeStructure, 10)
var SimpleScalarPropertiesRequest_foo *smithy.Schema

var SimpleScalarPropertiesRequest_stringValue *smithy.Schema

var SimpleScalarPropertiesRequest_trueBooleanValue *smithy.Schema

var SimpleScalarPropertiesRequest_falseBooleanValue *smithy.Schema

var SimpleScalarPropertiesRequest_byteValue *smithy.Schema

var SimpleScalarPropertiesRequest_shortValue *smithy.Schema

var SimpleScalarPropertiesRequest_integerValue *smithy.Schema

var SimpleScalarPropertiesRequest_longValue *smithy.Schema

var SimpleScalarPropertiesRequest_floatValue *smithy.Schema

var SimpleScalarPropertiesRequest_doubleValue *smithy.Schema

var SimpleScalarPropertiesResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "SimpleScalarPropertiesResponse",
}, smithy.ShapeTypeStructure, 10)
var SimpleScalarPropertiesResponse_foo *smithy.Schema

var SimpleScalarPropertiesResponse_stringValue *smithy.Schema

var SimpleScalarPropertiesResponse_trueBooleanValue *smithy.Schema

var SimpleScalarPropertiesResponse_falseBooleanValue *smithy.Schema

var SimpleScalarPropertiesResponse_byteValue *smithy.Schema

var SimpleScalarPropertiesResponse_shortValue *smithy.Schema

var SimpleScalarPropertiesResponse_integerValue *smithy.Schema

var SimpleScalarPropertiesResponse_longValue *smithy.Schema

var SimpleScalarPropertiesResponse_floatValue *smithy.Schema

var SimpleScalarPropertiesResponse_doubleValue *smithy.Schema

var TimestampFormatHeadersIO = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "TimestampFormatHeadersIO",
}, smithy.ShapeTypeStructure, 7)
var TimestampFormatHeadersIO_memberEpochSeconds *smithy.Schema

var TimestampFormatHeadersIO_memberHttpDate *smithy.Schema

var TimestampFormatHeadersIO_memberDateTime *smithy.Schema

var TimestampFormatHeadersIO_defaultFormat *smithy.Schema

var TimestampFormatHeadersIO_targetEpochSeconds *smithy.Schema

var TimestampFormatHeadersIO_targetHttpDate *smithy.Schema

var TimestampFormatHeadersIO_targetDateTime *smithy.Schema

var XmlAttributesInMiddleRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlAttributesInMiddleRequest",
}, smithy.ShapeTypeStructure, 1)
var XmlAttributesInMiddleRequest_payload *smithy.Schema

var XmlAttributesInMiddleResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlAttributesInMiddleResponse",
}, smithy.ShapeTypeStructure, 1)
var XmlAttributesInMiddleResponse_payload *smithy.Schema

var XmlAttributesRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlAttributesRequest",
}, smithy.ShapeTypeStructure, 2)
var XmlAttributesRequest_foo *smithy.Schema

var XmlAttributesRequest_attr *smithy.Schema

var XmlAttributesOnPayloadRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlAttributesOnPayloadRequest",
}, smithy.ShapeTypeStructure, 1)
var XmlAttributesOnPayloadRequest_payload *smithy.Schema

var XmlAttributesOnPayloadResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlAttributesOnPayloadResponse",
}, smithy.ShapeTypeStructure, 1)
var XmlAttributesOnPayloadResponse_payload *smithy.Schema

var XmlAttributesResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlAttributesResponse",
}, smithy.ShapeTypeStructure, 2)
var XmlAttributesResponse_foo *smithy.Schema

var XmlAttributesResponse_attr *smithy.Schema

var XmlBlobsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlBlobsRequest",
}, smithy.ShapeTypeStructure, 1)
var XmlBlobsRequest_data *smithy.Schema

var XmlBlobsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlBlobsResponse",
}, smithy.ShapeTypeStructure, 1)
var XmlBlobsResponse_data *smithy.Schema

var XmlEmptyBlobsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlEmptyBlobsRequest",
}, smithy.ShapeTypeStructure, 1)
var XmlEmptyBlobsRequest_data *smithy.Schema

var XmlEmptyBlobsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlEmptyBlobsResponse",
}, smithy.ShapeTypeStructure, 1)
var XmlEmptyBlobsResponse_data *smithy.Schema

var XmlEmptyListsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlEmptyListsRequest",
}, smithy.ShapeTypeStructure, 15)
var XmlEmptyListsRequest_stringList *smithy.Schema

var XmlEmptyListsRequest_stringSet *smithy.Schema

var XmlEmptyListsRequest_integerList *smithy.Schema

var XmlEmptyListsRequest_booleanList *smithy.Schema

var XmlEmptyListsRequest_timestampList *smithy.Schema

var XmlEmptyListsRequest_enumList *smithy.Schema

var XmlEmptyListsRequest_intEnumList *smithy.Schema

var XmlEmptyListsRequest_nestedStringList *smithy.Schema

var XmlEmptyListsRequest_renamedListMembers *smithy.Schema

var XmlEmptyListsRequest_flattenedList *smithy.Schema

var XmlEmptyListsRequest_flattenedList2 *smithy.Schema

var XmlEmptyListsRequest_flattenedListWithMemberNamespace *smithy.Schema

var XmlEmptyListsRequest_flattenedListWithNamespace *smithy.Schema

var XmlEmptyListsRequest_structureList *smithy.Schema

var XmlEmptyListsRequest_flattenedStructureList *smithy.Schema

var XmlEmptyListsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlEmptyListsResponse",
}, smithy.ShapeTypeStructure, 15)
var XmlEmptyListsResponse_stringList *smithy.Schema

var XmlEmptyListsResponse_stringSet *smithy.Schema

var XmlEmptyListsResponse_integerList *smithy.Schema

var XmlEmptyListsResponse_booleanList *smithy.Schema

var XmlEmptyListsResponse_timestampList *smithy.Schema

var XmlEmptyListsResponse_enumList *smithy.Schema

var XmlEmptyListsResponse_intEnumList *smithy.Schema

var XmlEmptyListsResponse_nestedStringList *smithy.Schema

var XmlEmptyListsResponse_renamedListMembers *smithy.Schema

var XmlEmptyListsResponse_flattenedList *smithy.Schema

var XmlEmptyListsResponse_flattenedList2 *smithy.Schema

var XmlEmptyListsResponse_flattenedListWithMemberNamespace *smithy.Schema

var XmlEmptyListsResponse_flattenedListWithNamespace *smithy.Schema

var XmlEmptyListsResponse_structureList *smithy.Schema

var XmlEmptyListsResponse_flattenedStructureList *smithy.Schema

var XmlEmptyMapsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlEmptyMapsRequest",
}, smithy.ShapeTypeStructure, 1)
var XmlEmptyMapsRequest_myMap *smithy.Schema

var XmlEmptyMapsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlEmptyMapsResponse",
}, smithy.ShapeTypeStructure, 1)
var XmlEmptyMapsResponse_myMap *smithy.Schema

var XmlEmptyStringsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlEmptyStringsRequest",
}, smithy.ShapeTypeStructure, 1)
var XmlEmptyStringsRequest_emptyString *smithy.Schema

var XmlEmptyStringsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlEmptyStringsResponse",
}, smithy.ShapeTypeStructure, 1)
var XmlEmptyStringsResponse_emptyString *smithy.Schema

var XmlEnumsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlEnumsRequest",
}, smithy.ShapeTypeStructure, 6)
var XmlEnumsRequest_fooEnum1 *smithy.Schema

var XmlEnumsRequest_fooEnum2 *smithy.Schema

var XmlEnumsRequest_fooEnum3 *smithy.Schema

var XmlEnumsRequest_fooEnumList *smithy.Schema

var XmlEnumsRequest_fooEnumSet *smithy.Schema

var XmlEnumsRequest_fooEnumMap *smithy.Schema

var XmlEnumsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlEnumsResponse",
}, smithy.ShapeTypeStructure, 6)
var XmlEnumsResponse_fooEnum1 *smithy.Schema

var XmlEnumsResponse_fooEnum2 *smithy.Schema

var XmlEnumsResponse_fooEnum3 *smithy.Schema

var XmlEnumsResponse_fooEnumList *smithy.Schema

var XmlEnumsResponse_fooEnumSet *smithy.Schema

var XmlEnumsResponse_fooEnumMap *smithy.Schema

var XmlIntEnumsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlIntEnumsRequest",
}, smithy.ShapeTypeStructure, 6)
var XmlIntEnumsRequest_intEnum1 *smithy.Schema

var XmlIntEnumsRequest_intEnum2 *smithy.Schema

var XmlIntEnumsRequest_intEnum3 *smithy.Schema

var XmlIntEnumsRequest_intEnumList *smithy.Schema

var XmlIntEnumsRequest_intEnumSet *smithy.Schema

var XmlIntEnumsRequest_intEnumMap *smithy.Schema

var XmlIntEnumsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlIntEnumsResponse",
}, smithy.ShapeTypeStructure, 6)
var XmlIntEnumsResponse_intEnum1 *smithy.Schema

var XmlIntEnumsResponse_intEnum2 *smithy.Schema

var XmlIntEnumsResponse_intEnum3 *smithy.Schema

var XmlIntEnumsResponse_intEnumList *smithy.Schema

var XmlIntEnumsResponse_intEnumSet *smithy.Schema

var XmlIntEnumsResponse_intEnumMap *smithy.Schema

var XmlListsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlListsRequest",
}, smithy.ShapeTypeStructure, 15)
var XmlListsRequest_stringList *smithy.Schema

var XmlListsRequest_stringSet *smithy.Schema

var XmlListsRequest_integerList *smithy.Schema

var XmlListsRequest_booleanList *smithy.Schema

var XmlListsRequest_timestampList *smithy.Schema

var XmlListsRequest_enumList *smithy.Schema

var XmlListsRequest_intEnumList *smithy.Schema

var XmlListsRequest_nestedStringList *smithy.Schema

var XmlListsRequest_renamedListMembers *smithy.Schema

var XmlListsRequest_flattenedList *smithy.Schema

var XmlListsRequest_flattenedList2 *smithy.Schema

var XmlListsRequest_flattenedListWithMemberNamespace *smithy.Schema

var XmlListsRequest_flattenedListWithNamespace *smithy.Schema

var XmlListsRequest_structureList *smithy.Schema

var XmlListsRequest_flattenedStructureList *smithy.Schema

var XmlListsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlListsResponse",
}, smithy.ShapeTypeStructure, 15)
var XmlListsResponse_stringList *smithy.Schema

var XmlListsResponse_stringSet *smithy.Schema

var XmlListsResponse_integerList *smithy.Schema

var XmlListsResponse_booleanList *smithy.Schema

var XmlListsResponse_timestampList *smithy.Schema

var XmlListsResponse_enumList *smithy.Schema

var XmlListsResponse_intEnumList *smithy.Schema

var XmlListsResponse_nestedStringList *smithy.Schema

var XmlListsResponse_renamedListMembers *smithy.Schema

var XmlListsResponse_flattenedList *smithy.Schema

var XmlListsResponse_flattenedList2 *smithy.Schema

var XmlListsResponse_flattenedListWithMemberNamespace *smithy.Schema

var XmlListsResponse_flattenedListWithNamespace *smithy.Schema

var XmlListsResponse_structureList *smithy.Schema

var XmlListsResponse_flattenedStructureList *smithy.Schema

var XmlMapsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlMapsRequest",
}, smithy.ShapeTypeStructure, 1)
var XmlMapsRequest_myMap *smithy.Schema

var XmlMapsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlMapsResponse",
}, smithy.ShapeTypeStructure, 1)
var XmlMapsResponse_myMap *smithy.Schema

var XmlMapsXmlNameRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlMapsXmlNameRequest",
}, smithy.ShapeTypeStructure, 1)
var XmlMapsXmlNameRequest_myMap *smithy.Schema

var XmlMapsXmlNameResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlMapsXmlNameResponse",
}, smithy.ShapeTypeStructure, 1)
var XmlMapsXmlNameResponse_myMap *smithy.Schema

var XmlMapWithXmlNamespaceRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlMapWithXmlNamespaceRequest",
}, smithy.ShapeTypeStructure, 1)
var XmlMapWithXmlNamespaceRequest_myMap *smithy.Schema

var XmlMapWithXmlNamespaceResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlMapWithXmlNamespaceResponse",
}, smithy.ShapeTypeStructure, 1)
var XmlMapWithXmlNamespaceResponse_myMap *smithy.Schema

var XmlNamespacesRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlNamespacesRequest",
}, smithy.ShapeTypeStructure, 1, &smithytraits.XMLNamespace{URI: "http://foo.com"})
var XmlNamespacesRequest_nested *smithy.Schema

var XmlNamespacesResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlNamespacesResponse",
}, smithy.ShapeTypeStructure, 1, &smithytraits.XMLNamespace{URI: "http://foo.com"})
var XmlNamespacesResponse_nested *smithy.Schema

var XmlTimestampsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlTimestampsRequest",
}, smithy.ShapeTypeStructure, 7)
var XmlTimestampsRequest_normal *smithy.Schema

var XmlTimestampsRequest_dateTime *smithy.Schema

var XmlTimestampsRequest_dateTimeOnTarget *smithy.Schema

var XmlTimestampsRequest_epochSeconds *smithy.Schema

var XmlTimestampsRequest_epochSecondsOnTarget *smithy.Schema

var XmlTimestampsRequest_httpDate *smithy.Schema

var XmlTimestampsRequest_httpDateOnTarget *smithy.Schema

var XmlTimestampsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlTimestampsResponse",
}, smithy.ShapeTypeStructure, 7)
var XmlTimestampsResponse_normal *smithy.Schema

var XmlTimestampsResponse_dateTime *smithy.Schema

var XmlTimestampsResponse_dateTimeOnTarget *smithy.Schema

var XmlTimestampsResponse_epochSeconds *smithy.Schema

var XmlTimestampsResponse_epochSecondsOnTarget *smithy.Schema

var XmlTimestampsResponse_httpDate *smithy.Schema

var XmlTimestampsResponse_httpDateOnTarget *smithy.Schema

var XmlUnionsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlUnionsRequest",
}, smithy.ShapeTypeStructure, 1)
var XmlUnionsRequest_unionValue *smithy.Schema

var XmlUnionsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restxml",
	Name:      "XmlUnionsResponse",
}, smithy.ShapeTypeStructure, 1)
var XmlUnionsResponse_unionValue *smithy.Schema

// Initialize schema members after all schemas are declared to avoid
// initialization cycles
func init() {
	ComplexNestedErrorData_Foo = ComplexNestedErrorData.AddMember("Foo", smithyprelude.String)

	ComplexError_Header = ComplexError.AddMember("Header", smithyprelude.String, &smithytraits.HTTPHeader{Name: "X-Header"})

	ComplexError_TopLevel = ComplexError.AddMember("TopLevel", smithyprelude.String)

	ComplexError_Nested = ComplexError.AddMember("Nested", ComplexNestedErrorData)

	_FlattenedXmlMapWithXmlNameInputOutputMap_key = _FlattenedXmlMapWithXmlNameInputOutputMap.AddMember("key", smithyprelude.String, &smithytraits.XMLName{Name: "K"})

	_FlattenedXmlMapWithXmlNameInputOutputMap_value = _FlattenedXmlMapWithXmlNameInputOutputMap.AddMember("value", smithyprelude.String, &smithytraits.XMLName{Name: "V"})

	_FlattenedXmlMapWithXmlNamespaceOutputMap_key = _FlattenedXmlMapWithXmlNamespaceOutputMap.AddMember("key", smithyprelude.String, &smithytraits.XMLNamespace{URI: "https://the-key.example.com"},
		&smithytraits.XMLName{Name: "K"})

	_FlattenedXmlMapWithXmlNamespaceOutputMap_value = _FlattenedXmlMapWithXmlNamespaceOutputMap.AddMember("value", smithyprelude.String, &smithytraits.XMLNamespace{URI: "https://the-value.example.com"},
		&smithytraits.XMLName{Name: "V"})

	_FooPrefixHeaders_key = _FooPrefixHeaders.AddMember("key", smithyprelude.String)

	_FooPrefixHeaders_value = _FooPrefixHeaders.AddMember("value", smithyprelude.String)

	InvalidGreeting_Message = InvalidGreeting.AddMember("Message", smithyprelude.String)

	_ListWithMemberNamespace_member = _ListWithMemberNamespace.AddMember("member", smithyprelude.String, &smithytraits.XMLNamespace{URI: "https://xml-member.example.com"})

	_ListWithNamespace_member = _ListWithNamespace.AddMember("member", smithyprelude.String)

	FooEnum_FOO = FooEnum.AddMember("FOO", smithyprelude.Unit)

	FooEnum_BAZ = FooEnum.AddMember("BAZ", smithyprelude.Unit)

	FooEnum_BAR = FooEnum.AddMember("BAR", smithyprelude.Unit)

	FooEnum_ONE = FooEnum.AddMember("ONE", smithyprelude.Unit)

	FooEnum_ZERO = FooEnum.AddMember("ZERO", smithyprelude.Unit)

	_FooEnumMap_key = _FooEnumMap.AddMember("key", smithyprelude.String)

	_FooEnumMap_value = _FooEnumMap.AddMember("value", FooEnum)

	_NestedMap_key = _NestedMap.AddMember("key", smithyprelude.String)

	_NestedMap_value = _NestedMap.AddMember("value", _FooEnumMap)

	NestedPayload_greeting = NestedPayload.AddMember("greeting", smithyprelude.String)

	NestedPayload_name = NestedPayload.AddMember("name", smithyprelude.String)

	_NestedXmlMapWithXmlNameInnerMap_key = _NestedXmlMapWithXmlNameInnerMap.AddMember("key", smithyprelude.String, &smithytraits.XMLName{Name: "InnerKey"})

	_NestedXmlMapWithXmlNameInnerMap_value = _NestedXmlMapWithXmlNameInnerMap.AddMember("value", smithyprelude.String, &smithytraits.XMLName{Name: "InnerValue"})

	_NestedXmlMapWithXmlNameMap_key = _NestedXmlMapWithXmlNameMap.AddMember("key", smithyprelude.String, &smithytraits.XMLName{Name: "OuterKey"})

	_NestedXmlMapWithXmlNameMap_value = _NestedXmlMapWithXmlNameMap.AddMember("value", _NestedXmlMapWithXmlNameInnerMap)

	PayloadWithXmlName_name = PayloadWithXmlName.AddMember("name", smithyprelude.String)

	PayloadWithXmlNamespace_name = PayloadWithXmlNamespace.AddMember("name", smithyprelude.String)

	PayloadWithXmlNamespaceAndPrefix_name = PayloadWithXmlNamespaceAndPrefix.AddMember("name", smithyprelude.String)

	RecursiveShapesInputOutputNested2_bar = RecursiveShapesInputOutputNested2.AddMember("bar", smithyprelude.String)

	RecursiveShapesInputOutputNested2_recursiveMember = RecursiveShapesInputOutputNested2.AddMember("recursiveMember", RecursiveShapesInputOutputNested1)

	RecursiveShapesInputOutputNested1_foo = RecursiveShapesInputOutputNested1.AddMember("foo", smithyprelude.String)

	RecursiveShapesInputOutputNested1_nested = RecursiveShapesInputOutputNested1.AddMember("nested", RecursiveShapesInputOutputNested2)

	_RenamedListMembers_member = _RenamedListMembers.AddMember("member", smithyprelude.String, &smithytraits.XMLName{Name: "item"})

	StringEnum_V = StringEnum.AddMember("V", smithyprelude.Unit)

	StructureListMember_a = StructureListMember.AddMember("a", smithyprelude.String, &smithytraits.XMLName{Name: "value"})

	StructureListMember_b = StructureListMember.AddMember("b", smithyprelude.String, &smithytraits.XMLName{Name: "other"})

	_StructureList_member = _StructureList.AddMember("member", StructureListMember, &smithytraits.XMLName{Name: "item"})

	UnionPayload_greeting = UnionPayload.AddMember("greeting", smithyprelude.String)

	XmlAttributesInMiddlePayloadRequest_foo = XmlAttributesInMiddlePayloadRequest.AddMember("foo", smithyprelude.String)

	XmlAttributesInMiddlePayloadRequest_attr = XmlAttributesInMiddlePayloadRequest.AddMember("attr", smithyprelude.String, &smithytraits.XMLName{Name: "test"},
		&smithytraits.XMLAttribute{})

	XmlAttributesInMiddlePayloadRequest_baz = XmlAttributesInMiddlePayloadRequest.AddMember("baz", smithyprelude.String)

	XmlAttributesInMiddlePayloadResponse_foo = XmlAttributesInMiddlePayloadResponse.AddMember("foo", smithyprelude.String)

	XmlAttributesInMiddlePayloadResponse_attr = XmlAttributesInMiddlePayloadResponse.AddMember("attr", smithyprelude.String, &smithytraits.XMLName{Name: "test"},
		&smithytraits.XMLAttribute{})

	XmlAttributesInMiddlePayloadResponse_baz = XmlAttributesInMiddlePayloadResponse.AddMember("baz", smithyprelude.String)

	XmlAttributesPayloadRequest_foo = XmlAttributesPayloadRequest.AddMember("foo", smithyprelude.String)

	XmlAttributesPayloadRequest_attr = XmlAttributesPayloadRequest.AddMember("attr", smithyprelude.String, &smithytraits.XMLName{Name: "test"},
		&smithytraits.XMLAttribute{})

	XmlAttributesPayloadResponse_foo = XmlAttributesPayloadResponse.AddMember("foo", smithyprelude.String)

	XmlAttributesPayloadResponse_attr = XmlAttributesPayloadResponse.AddMember("attr", smithyprelude.String, &smithytraits.XMLName{Name: "test"},
		&smithytraits.XMLAttribute{})

	GreetingStruct_hi = GreetingStruct.AddMember("hi", smithyprelude.String)

	_XmlMapsInputOutputMap_key = _XmlMapsInputOutputMap.AddMember("key", smithyprelude.String)

	_XmlMapsInputOutputMap_value = _XmlMapsInputOutputMap.AddMember("value", GreetingStruct)

	_XmlMapsXmlNameInputOutputMap_key = _XmlMapsXmlNameInputOutputMap.AddMember("key", smithyprelude.String, &smithytraits.XMLName{Name: "Attribute"})

	_XmlMapsXmlNameInputOutputMap_value = _XmlMapsXmlNameInputOutputMap.AddMember("value", GreetingStruct, &smithytraits.XMLName{Name: "Setting"})

	_XmlMapWithXmlNamespaceInputOutputMap_key = _XmlMapWithXmlNamespaceInputOutputMap.AddMember("key", smithyprelude.String, &smithytraits.XMLNamespace{URI: "https://the-key.example.com"},
		&smithytraits.XMLName{Name: "K"})

	_XmlMapWithXmlNamespaceInputOutputMap_value = _XmlMapWithXmlNamespaceInputOutputMap.AddMember("value", smithyprelude.String, &smithytraits.XMLNamespace{URI: "https://the-value.example.com"},
		&smithytraits.XMLName{Name: "V"})

	_XmlNamespacedList_member = _XmlNamespacedList.AddMember("member", smithyprelude.String, &smithytraits.XMLNamespace{URI: "http://bux.com"})

	XmlNamespaceNested_foo = XmlNamespaceNested.AddMember("foo", smithyprelude.String, &smithytraits.XMLNamespace{URI: "http://baz.com",
		Prefix: "baz"})

	XmlNamespaceNested_values = XmlNamespaceNested.AddMember("values", _XmlNamespacedList, &smithytraits.XMLNamespace{URI: "http://qux.com"})

	XmlNestedUnionStruct_stringValue = XmlNestedUnionStruct.AddMember("stringValue", smithyprelude.String)

	XmlNestedUnionStruct_booleanValue = XmlNestedUnionStruct.AddMember("booleanValue", smithyprelude.Boolean)

	XmlNestedUnionStruct_byteValue = XmlNestedUnionStruct.AddMember("byteValue", smithyprelude.Byte)

	XmlNestedUnionStruct_shortValue = XmlNestedUnionStruct.AddMember("shortValue", smithyprelude.Short)

	XmlNestedUnionStruct_integerValue = XmlNestedUnionStruct.AddMember("integerValue", smithyprelude.Integer)

	XmlNestedUnionStruct_longValue = XmlNestedUnionStruct.AddMember("longValue", smithyprelude.Long)

	XmlNestedUnionStruct_floatValue = XmlNestedUnionStruct.AddMember("floatValue", smithyprelude.Float)

	XmlNestedUnionStruct_doubleValue = XmlNestedUnionStruct.AddMember("doubleValue", smithyprelude.Double)

	XmlUnionShape_stringValue = XmlUnionShape.AddMember("stringValue", smithyprelude.String)

	XmlUnionShape_booleanValue = XmlUnionShape.AddMember("booleanValue", smithyprelude.Boolean)

	XmlUnionShape_byteValue = XmlUnionShape.AddMember("byteValue", smithyprelude.Byte)

	XmlUnionShape_shortValue = XmlUnionShape.AddMember("shortValue", smithyprelude.Short)

	XmlUnionShape_integerValue = XmlUnionShape.AddMember("integerValue", smithyprelude.Integer)

	XmlUnionShape_longValue = XmlUnionShape.AddMember("longValue", smithyprelude.Long)

	XmlUnionShape_floatValue = XmlUnionShape.AddMember("floatValue", smithyprelude.Float)

	XmlUnionShape_doubleValue = XmlUnionShape.AddMember("doubleValue", smithyprelude.Double)

	XmlUnionShape_unionValue = XmlUnionShape.AddMember("unionValue", XmlUnionShape)

	XmlUnionShape_structValue = XmlUnionShape.AddMember("structValue", XmlNestedUnionStruct)

	_BooleanList_member = _BooleanList.AddMember("member", smithyprelude.Boolean)

	_DoubleList_member = _DoubleList.AddMember("member", smithyprelude.Double)

	_FooEnumList_member = _FooEnumList.AddMember("member", FooEnum)

	_FooEnumSet_member = _FooEnumSet.AddMember("member", FooEnum)

	_IntegerEnum_A = _IntegerEnum.AddMember("A", smithyprelude.Unit)

	_IntegerEnum_B = _IntegerEnum.AddMember("B", smithyprelude.Unit)

	_IntegerEnum_C = _IntegerEnum.AddMember("C", smithyprelude.Unit)

	_IntegerEnumList_member = _IntegerEnumList.AddMember("member", _IntegerEnum)

	_IntegerEnumMap_key = _IntegerEnumMap.AddMember("key", smithyprelude.String)

	_IntegerEnumMap_value = _IntegerEnumMap.AddMember("value", _IntegerEnum)

	_IntegerEnumSet_member = _IntegerEnumSet.AddMember("member", _IntegerEnum)

	_IntegerList_member = _IntegerList.AddMember("member", smithyprelude.Integer)

	_IntegerSet_member = _IntegerSet.AddMember("member", smithyprelude.Integer)

	_StringList_member = _StringList.AddMember("member", smithyprelude.String)

	_NestedStringList_member = _NestedStringList.AddMember("member", _StringList)

	_StringListMap_key = _StringListMap.AddMember("key", smithyprelude.String)

	_StringListMap_value = _StringListMap.AddMember("value", _StringList)

	_StringMap_key = _StringMap.AddMember("key", smithyprelude.String)

	_StringMap_value = _StringMap.AddMember("value", smithyprelude.String)

	_StringSet_member = _StringSet.AddMember("member", smithyprelude.String)

	_TimestampList_member = _TimestampList.AddMember("member", smithyprelude.Timestamp)

	AllQueryStringTypesInput_queryString = AllQueryStringTypesInput.AddMember("queryString", smithyprelude.String, &smithytraits.HTTPQuery{Name: "String"})

	AllQueryStringTypesInput_queryStringList = AllQueryStringTypesInput.AddMember("queryStringList", _StringList, &smithytraits.HTTPQuery{Name: "StringList"})

	AllQueryStringTypesInput_queryStringSet = AllQueryStringTypesInput.AddMember("queryStringSet", _StringSet, &smithytraits.HTTPQuery{Name: "StringSet"})

	AllQueryStringTypesInput_queryByte = AllQueryStringTypesInput.AddMember("queryByte", smithyprelude.Byte, &smithytraits.HTTPQuery{Name: "Byte"})

	AllQueryStringTypesInput_queryShort = AllQueryStringTypesInput.AddMember("queryShort", smithyprelude.Short, &smithytraits.HTTPQuery{Name: "Short"})

	AllQueryStringTypesInput_queryInteger = AllQueryStringTypesInput.AddMember("queryInteger", smithyprelude.Integer, &smithytraits.HTTPQuery{Name: "Integer"})

	AllQueryStringTypesInput_queryIntegerList = AllQueryStringTypesInput.AddMember("queryIntegerList", _IntegerList, &smithytraits.HTTPQuery{Name: "IntegerList"})

	AllQueryStringTypesInput_queryIntegerSet = AllQueryStringTypesInput.AddMember("queryIntegerSet", _IntegerSet, &smithytraits.HTTPQuery{Name: "IntegerSet"})

	AllQueryStringTypesInput_queryLong = AllQueryStringTypesInput.AddMember("queryLong", smithyprelude.Long, &smithytraits.HTTPQuery{Name: "Long"})

	AllQueryStringTypesInput_queryFloat = AllQueryStringTypesInput.AddMember("queryFloat", smithyprelude.Float, &smithytraits.HTTPQuery{Name: "Float"})

	AllQueryStringTypesInput_queryDouble = AllQueryStringTypesInput.AddMember("queryDouble", smithyprelude.Double, &smithytraits.HTTPQuery{Name: "Double"})

	AllQueryStringTypesInput_queryDoubleList = AllQueryStringTypesInput.AddMember("queryDoubleList", _DoubleList, &smithytraits.HTTPQuery{Name: "DoubleList"})

	AllQueryStringTypesInput_queryBoolean = AllQueryStringTypesInput.AddMember("queryBoolean", smithyprelude.Boolean, &smithytraits.HTTPQuery{Name: "Boolean"})

	AllQueryStringTypesInput_queryBooleanList = AllQueryStringTypesInput.AddMember("queryBooleanList", _BooleanList, &smithytraits.HTTPQuery{Name: "BooleanList"})

	AllQueryStringTypesInput_queryTimestamp = AllQueryStringTypesInput.AddMember("queryTimestamp", smithyprelude.Timestamp, &smithytraits.HTTPQuery{Name: "Timestamp"})

	AllQueryStringTypesInput_queryTimestampList = AllQueryStringTypesInput.AddMember("queryTimestampList", _TimestampList, &smithytraits.HTTPQuery{Name: "TimestampList"})

	AllQueryStringTypesInput_queryEnum = AllQueryStringTypesInput.AddMember("queryEnum", FooEnum, &smithytraits.HTTPQuery{Name: "Enum"})

	AllQueryStringTypesInput_queryEnumList = AllQueryStringTypesInput.AddMember("queryEnumList", _FooEnumList, &smithytraits.HTTPQuery{Name: "EnumList"})

	AllQueryStringTypesInput_queryIntegerEnum = AllQueryStringTypesInput.AddMember("queryIntegerEnum", _IntegerEnum, &smithytraits.HTTPQuery{Name: "IntegerEnum"})

	AllQueryStringTypesInput_queryIntegerEnumList = AllQueryStringTypesInput.AddMember("queryIntegerEnumList", _IntegerEnumList, &smithytraits.HTTPQuery{Name: "IntegerEnumList"})

	AllQueryStringTypesInput_queryParamsMapOfStrings = AllQueryStringTypesInput.AddMember("queryParamsMapOfStrings", _StringMap, &smithytraits.HTTPQueryParams{})

	BodyWithXmlNameInputOutput_nested = BodyWithXmlNameInputOutput.AddMember("nested", PayloadWithXmlName)

	ConstantAndVariableQueryStringInput_baz = ConstantAndVariableQueryStringInput.AddMember("baz", smithyprelude.String, &smithytraits.HTTPQuery{Name: "baz"})

	ConstantAndVariableQueryStringInput_maybeSet = ConstantAndVariableQueryStringInput.AddMember("maybeSet", smithyprelude.String, &smithytraits.HTTPQuery{Name: "maybeSet"})

	ConstantQueryStringInput_hello = ConstantQueryStringInput.AddMember("hello", smithyprelude.String, &smithytraits.HTTPLabel{})

	ContentTypeParametersInput_value = ContentTypeParametersInput.AddMember("value", smithyprelude.Integer)

	DatetimeOffsetsOutput_datetime = DatetimeOffsetsOutput.AddMember("datetime", _DateTime)

	HostLabelHeaderInput_accountId = HostLabelHeaderInput.AddMember("accountId", smithyprelude.String, &smithytraits.HostLabel{},

		&smithytraits.HTTPHeader{Name: "X-Amz-Account-Id"})

	EndpointWithHostLabelOperationRequest_label = EndpointWithHostLabelOperationRequest.AddMember("label", smithyprelude.String, &smithytraits.HostLabel{})

	FlattenedXmlMapRequest_myMap = FlattenedXmlMapRequest.AddMember("myMap", _FooEnumMap, &smithytraits.XMLFlattened{})

	FlattenedXmlMapResponse_myMap = FlattenedXmlMapResponse.AddMember("myMap", _FooEnumMap, &smithytraits.XMLFlattened{})

	FlattenedXmlMapWithXmlNameRequest_myMap = FlattenedXmlMapWithXmlNameRequest.AddMember("myMap", _FlattenedXmlMapWithXmlNameInputOutputMap, &smithytraits.XMLName{Name: "KVP"},
		&smithytraits.XMLFlattened{})

	FlattenedXmlMapWithXmlNameResponse_myMap = FlattenedXmlMapWithXmlNameResponse.AddMember("myMap", _FlattenedXmlMapWithXmlNameInputOutputMap, &smithytraits.XMLName{Name: "KVP"},
		&smithytraits.XMLFlattened{})

	FlattenedXmlMapWithXmlNamespaceOutput_myMap = FlattenedXmlMapWithXmlNamespaceOutput.AddMember("myMap", _FlattenedXmlMapWithXmlNamespaceOutputMap, &smithytraits.XMLName{Name: "KVP"},
		&smithytraits.XMLFlattened{},
		&smithytraits.XMLNamespace{URI: "https://the-member.example.com"})

	FractionalSecondsOutput_datetime = FractionalSecondsOutput.AddMember("datetime", _DateTime)

	GreetingWithErrorsOutput_greeting = GreetingWithErrorsOutput.AddMember("greeting", smithyprelude.String, &smithytraits.HTTPHeader{Name: "X-Greeting"})

	HttpEmptyPrefixHeadersInput_prefixHeaders = HttpEmptyPrefixHeadersInput.AddMember("prefixHeaders", _StringMap, &smithytraits.HTTPPrefixHeaders{Prefix: ""})

	HttpEmptyPrefixHeadersInput_specificHeader = HttpEmptyPrefixHeadersInput.AddMember("specificHeader", smithyprelude.String, &smithytraits.HTTPHeader{Name: "hello"})

	HttpEmptyPrefixHeadersOutput_prefixHeaders = HttpEmptyPrefixHeadersOutput.AddMember("prefixHeaders", _StringMap, &smithytraits.HTTPPrefixHeaders{Prefix: ""})

	HttpEmptyPrefixHeadersOutput_specificHeader = HttpEmptyPrefixHeadersOutput.AddMember("specificHeader", smithyprelude.String, &smithytraits.HTTPHeader{Name: "hello"})

	EnumPayloadInput_payload = EnumPayloadInput.AddMember("payload", StringEnum, &smithytraits.HTTPPayload{})

	HttpPayloadTraitsInputOutput_foo = HttpPayloadTraitsInputOutput.AddMember("foo", smithyprelude.String, &smithytraits.HTTPHeader{Name: "X-Foo"})

	HttpPayloadTraitsInputOutput_blob = HttpPayloadTraitsInputOutput.AddMember("blob", smithyprelude.Blob, &smithytraits.HTTPPayload{})

	HttpPayloadTraitsWithMediaTypeInputOutput_foo = HttpPayloadTraitsWithMediaTypeInputOutput.AddMember("foo", smithyprelude.String, &smithytraits.HTTPHeader{Name: "X-Foo"})

	HttpPayloadTraitsWithMediaTypeInputOutput_blob = HttpPayloadTraitsWithMediaTypeInputOutput.AddMember("blob", _TextPlainBlob, &smithytraits.HTTPPayload{})

	HttpPayloadWithMemberXmlNameInputOutput_nested = HttpPayloadWithMemberXmlNameInputOutput.AddMember("nested", PayloadWithXmlName, &smithytraits.HTTPPayload{},
		&smithytraits.XMLName{Name: "Hola"})

	HttpPayloadWithStructureInputOutput_nested = HttpPayloadWithStructureInputOutput.AddMember("nested", NestedPayload, &smithytraits.HTTPPayload{})

	HttpPayloadWithUnionInputOutput_nested = HttpPayloadWithUnionInputOutput.AddMember("nested", UnionPayload, &smithytraits.HTTPPayload{})

	HttpPayloadWithXmlNameInputOutput_nested = HttpPayloadWithXmlNameInputOutput.AddMember("nested", PayloadWithXmlName, &smithytraits.HTTPPayload{})

	HttpPayloadWithXmlNamespaceAndPrefixInputOutput_nested = HttpPayloadWithXmlNamespaceAndPrefixInputOutput.AddMember("nested", PayloadWithXmlNamespaceAndPrefix, &smithytraits.HTTPPayload{})

	HttpPayloadWithXmlNamespaceInputOutput_nested = HttpPayloadWithXmlNamespaceInputOutput.AddMember("nested", PayloadWithXmlNamespace, &smithytraits.HTTPPayload{})

	HttpPrefixHeadersInputOutput_foo = HttpPrefixHeadersInputOutput.AddMember("foo", smithyprelude.String, &smithytraits.HTTPHeader{Name: "x-foo"})

	HttpPrefixHeadersInputOutput_fooMap = HttpPrefixHeadersInputOutput.AddMember("fooMap", _FooPrefixHeaders, &smithytraits.HTTPPrefixHeaders{Prefix: "x-foo-"})

	HttpRequestWithFloatLabelsInput_float = HttpRequestWithFloatLabelsInput.AddMember("float", smithyprelude.Float, &smithytraits.HTTPLabel{})

	HttpRequestWithFloatLabelsInput_double = HttpRequestWithFloatLabelsInput.AddMember("double", smithyprelude.Double, &smithytraits.HTTPLabel{})

	HttpRequestWithGreedyLabelInPathInput_foo = HttpRequestWithGreedyLabelInPathInput.AddMember("foo", smithyprelude.String, &smithytraits.HTTPLabel{})

	HttpRequestWithGreedyLabelInPathInput_baz = HttpRequestWithGreedyLabelInPathInput.AddMember("baz", smithyprelude.String, &smithytraits.HTTPLabel{})

	HttpRequestWithLabelsAndTimestampFormatInput_memberEpochSeconds = HttpRequestWithLabelsAndTimestampFormatInput.AddMember("memberEpochSeconds", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "epoch-seconds"},

		&smithytraits.HTTPLabel{})

	HttpRequestWithLabelsAndTimestampFormatInput_memberHttpDate = HttpRequestWithLabelsAndTimestampFormatInput.AddMember("memberHttpDate", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "http-date"},

		&smithytraits.HTTPLabel{})

	HttpRequestWithLabelsAndTimestampFormatInput_memberDateTime = HttpRequestWithLabelsAndTimestampFormatInput.AddMember("memberDateTime", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "date-time"},

		&smithytraits.HTTPLabel{})

	HttpRequestWithLabelsAndTimestampFormatInput_defaultFormat = HttpRequestWithLabelsAndTimestampFormatInput.AddMember("defaultFormat", smithyprelude.Timestamp, &smithytraits.HTTPLabel{})

	HttpRequestWithLabelsAndTimestampFormatInput_targetEpochSeconds = HttpRequestWithLabelsAndTimestampFormatInput.AddMember("targetEpochSeconds", _EpochSeconds, &smithytraits.HTTPLabel{})

	HttpRequestWithLabelsAndTimestampFormatInput_targetHttpDate = HttpRequestWithLabelsAndTimestampFormatInput.AddMember("targetHttpDate", _HttpDate, &smithytraits.HTTPLabel{})

	HttpRequestWithLabelsAndTimestampFormatInput_targetDateTime = HttpRequestWithLabelsAndTimestampFormatInput.AddMember("targetDateTime", _DateTime, &smithytraits.HTTPLabel{})

	HttpRequestWithLabelsInput_string = HttpRequestWithLabelsInput.AddMember("string", smithyprelude.String, &smithytraits.HTTPLabel{})

	HttpRequestWithLabelsInput_short = HttpRequestWithLabelsInput.AddMember("short", smithyprelude.Short, &smithytraits.HTTPLabel{})

	HttpRequestWithLabelsInput_integer = HttpRequestWithLabelsInput.AddMember("integer", smithyprelude.Integer, &smithytraits.HTTPLabel{})

	HttpRequestWithLabelsInput_long = HttpRequestWithLabelsInput.AddMember("long", smithyprelude.Long, &smithytraits.HTTPLabel{})

	HttpRequestWithLabelsInput_float = HttpRequestWithLabelsInput.AddMember("float", smithyprelude.Float, &smithytraits.HTTPLabel{})

	HttpRequestWithLabelsInput_double = HttpRequestWithLabelsInput.AddMember("double", smithyprelude.Double, &smithytraits.HTTPLabel{})

	HttpRequestWithLabelsInput_boolean = HttpRequestWithLabelsInput.AddMember("boolean", smithyprelude.Boolean, &smithytraits.HTTPLabel{})

	HttpRequestWithLabelsInput_timestamp = HttpRequestWithLabelsInput.AddMember("timestamp", smithyprelude.Timestamp, &smithytraits.HTTPLabel{})

	HttpResponseCodeOutput_Status = HttpResponseCodeOutput.AddMember("Status", smithyprelude.Integer, &smithytraits.HTTPResponseCode{})

	StringPayloadInput_payload = StringPayloadInput.AddMember("payload", smithyprelude.String, &smithytraits.HTTPPayload{})

	IgnoreQueryParamsInResponseOutput_baz = IgnoreQueryParamsInResponseOutput.AddMember("baz", smithyprelude.String, &smithytraits.HTTPQuery{Name: "baz"})

	InputAndOutputWithHeadersIO_headerString = InputAndOutputWithHeadersIO.AddMember("headerString", smithyprelude.String, &smithytraits.HTTPHeader{Name: "X-String"})

	InputAndOutputWithHeadersIO_headerByte = InputAndOutputWithHeadersIO.AddMember("headerByte", smithyprelude.Byte, &smithytraits.HTTPHeader{Name: "X-Byte"})

	InputAndOutputWithHeadersIO_headerShort = InputAndOutputWithHeadersIO.AddMember("headerShort", smithyprelude.Short, &smithytraits.HTTPHeader{Name: "X-Short"})

	InputAndOutputWithHeadersIO_headerInteger = InputAndOutputWithHeadersIO.AddMember("headerInteger", smithyprelude.Integer, &smithytraits.HTTPHeader{Name: "X-Integer"})

	InputAndOutputWithHeadersIO_headerLong = InputAndOutputWithHeadersIO.AddMember("headerLong", smithyprelude.Long, &smithytraits.HTTPHeader{Name: "X-Long"})

	InputAndOutputWithHeadersIO_headerFloat = InputAndOutputWithHeadersIO.AddMember("headerFloat", smithyprelude.Float, &smithytraits.HTTPHeader{Name: "X-Float"})

	InputAndOutputWithHeadersIO_headerDouble = InputAndOutputWithHeadersIO.AddMember("headerDouble", smithyprelude.Double, &smithytraits.HTTPHeader{Name: "X-Double"})

	InputAndOutputWithHeadersIO_headerTrueBool = InputAndOutputWithHeadersIO.AddMember("headerTrueBool", smithyprelude.Boolean, &smithytraits.HTTPHeader{Name: "X-Boolean1"})

	InputAndOutputWithHeadersIO_headerFalseBool = InputAndOutputWithHeadersIO.AddMember("headerFalseBool", smithyprelude.Boolean, &smithytraits.HTTPHeader{Name: "X-Boolean2"})

	InputAndOutputWithHeadersIO_headerStringList = InputAndOutputWithHeadersIO.AddMember("headerStringList", _StringList, &smithytraits.HTTPHeader{Name: "X-StringList"})

	InputAndOutputWithHeadersIO_headerStringSet = InputAndOutputWithHeadersIO.AddMember("headerStringSet", _StringSet, &smithytraits.HTTPHeader{Name: "X-StringSet"})

	InputAndOutputWithHeadersIO_headerIntegerList = InputAndOutputWithHeadersIO.AddMember("headerIntegerList", _IntegerList, &smithytraits.HTTPHeader{Name: "X-IntegerList"})

	InputAndOutputWithHeadersIO_headerBooleanList = InputAndOutputWithHeadersIO.AddMember("headerBooleanList", _BooleanList, &smithytraits.HTTPHeader{Name: "X-BooleanList"})

	InputAndOutputWithHeadersIO_headerTimestampList = InputAndOutputWithHeadersIO.AddMember("headerTimestampList", _TimestampList, &smithytraits.HTTPHeader{Name: "X-TimestampList"})

	InputAndOutputWithHeadersIO_headerEnum = InputAndOutputWithHeadersIO.AddMember("headerEnum", FooEnum, &smithytraits.HTTPHeader{Name: "X-Enum"})

	InputAndOutputWithHeadersIO_headerEnumList = InputAndOutputWithHeadersIO.AddMember("headerEnumList", _FooEnumList, &smithytraits.HTTPHeader{Name: "X-EnumList"})

	NestedXmlMapsRequest_nestedMap = NestedXmlMapsRequest.AddMember("nestedMap", _NestedMap)

	NestedXmlMapsRequest_flatNestedMap = NestedXmlMapsRequest.AddMember("flatNestedMap", _NestedMap, &smithytraits.XMLFlattened{})

	NestedXmlMapsResponse_nestedMap = NestedXmlMapsResponse.AddMember("nestedMap", _NestedMap)

	NestedXmlMapsResponse_flatNestedMap = NestedXmlMapsResponse.AddMember("flatNestedMap", _NestedMap, &smithytraits.XMLFlattened{})

	NestedXmlMapWithXmlNameRequest_nestedXmlMapWithXmlNameMap = NestedXmlMapWithXmlNameRequest.AddMember("nestedXmlMapWithXmlNameMap", _NestedXmlMapWithXmlNameMap)

	NestedXmlMapWithXmlNameResponse_nestedXmlMapWithXmlNameMap = NestedXmlMapWithXmlNameResponse.AddMember("nestedXmlMapWithXmlNameMap", _NestedXmlMapWithXmlNameMap)

	NullAndEmptyHeadersIO_a = NullAndEmptyHeadersIO.AddMember("a", smithyprelude.String, &smithytraits.HTTPHeader{Name: "X-A"})

	NullAndEmptyHeadersIO_b = NullAndEmptyHeadersIO.AddMember("b", smithyprelude.String, &smithytraits.HTTPHeader{Name: "X-B"})

	NullAndEmptyHeadersIO_c = NullAndEmptyHeadersIO.AddMember("c", _StringList, &smithytraits.HTTPHeader{Name: "X-C"})

	OmitsNullSerializesEmptyStringInput_nullValue = OmitsNullSerializesEmptyStringInput.AddMember("nullValue", smithyprelude.String, &smithytraits.HTTPQuery{Name: "Null"})

	OmitsNullSerializesEmptyStringInput_emptyString = OmitsNullSerializesEmptyStringInput.AddMember("emptyString", smithyprelude.String, &smithytraits.HTTPQuery{Name: "Empty"})

	PutWithContentEncodingInput_encoding = PutWithContentEncodingInput.AddMember("encoding", smithyprelude.String, &smithytraits.HTTPHeader{Name: "Content-Encoding"})

	PutWithContentEncodingInput_data = PutWithContentEncodingInput.AddMember("data", smithyprelude.String)

	QueryIdempotencyTokenAutoFillInput_token = QueryIdempotencyTokenAutoFillInput.AddMember("token", smithyprelude.String, &smithytraits.HTTPQuery{Name: "token"})

	QueryParamsAsStringListMapInput_qux = QueryParamsAsStringListMapInput.AddMember("qux", smithyprelude.String, &smithytraits.HTTPQuery{Name: "corge"})

	QueryParamsAsStringListMapInput_foo = QueryParamsAsStringListMapInput.AddMember("foo", _StringListMap, &smithytraits.HTTPQueryParams{})

	QueryPrecedenceInput_foo = QueryPrecedenceInput.AddMember("foo", smithyprelude.String, &smithytraits.HTTPQuery{Name: "bar"})

	QueryPrecedenceInput_baz = QueryPrecedenceInput.AddMember("baz", _StringMap, &smithytraits.HTTPQueryParams{})

	RecursiveShapesRequest_nested = RecursiveShapesRequest.AddMember("nested", RecursiveShapesInputOutputNested1)

	RecursiveShapesResponse_nested = RecursiveShapesResponse.AddMember("nested", RecursiveShapesInputOutputNested1)

	SimpleScalarPropertiesRequest_foo = SimpleScalarPropertiesRequest.AddMember("foo", smithyprelude.String, &smithytraits.HTTPHeader{Name: "X-Foo"})

	SimpleScalarPropertiesRequest_stringValue = SimpleScalarPropertiesRequest.AddMember("stringValue", smithyprelude.String)

	SimpleScalarPropertiesRequest_trueBooleanValue = SimpleScalarPropertiesRequest.AddMember("trueBooleanValue", smithyprelude.Boolean)

	SimpleScalarPropertiesRequest_falseBooleanValue = SimpleScalarPropertiesRequest.AddMember("falseBooleanValue", smithyprelude.Boolean)

	SimpleScalarPropertiesRequest_byteValue = SimpleScalarPropertiesRequest.AddMember("byteValue", smithyprelude.Byte)

	SimpleScalarPropertiesRequest_shortValue = SimpleScalarPropertiesRequest.AddMember("shortValue", smithyprelude.Short)

	SimpleScalarPropertiesRequest_integerValue = SimpleScalarPropertiesRequest.AddMember("integerValue", smithyprelude.Integer)

	SimpleScalarPropertiesRequest_longValue = SimpleScalarPropertiesRequest.AddMember("longValue", smithyprelude.Long)

	SimpleScalarPropertiesRequest_floatValue = SimpleScalarPropertiesRequest.AddMember("floatValue", smithyprelude.Float)

	SimpleScalarPropertiesRequest_doubleValue = SimpleScalarPropertiesRequest.AddMember("doubleValue", smithyprelude.Double, &smithytraits.XMLName{Name: "DoubleDribble"})

	SimpleScalarPropertiesResponse_foo = SimpleScalarPropertiesResponse.AddMember("foo", smithyprelude.String, &smithytraits.HTTPHeader{Name: "X-Foo"})

	SimpleScalarPropertiesResponse_stringValue = SimpleScalarPropertiesResponse.AddMember("stringValue", smithyprelude.String)

	SimpleScalarPropertiesResponse_trueBooleanValue = SimpleScalarPropertiesResponse.AddMember("trueBooleanValue", smithyprelude.Boolean)

	SimpleScalarPropertiesResponse_falseBooleanValue = SimpleScalarPropertiesResponse.AddMember("falseBooleanValue", smithyprelude.Boolean)

	SimpleScalarPropertiesResponse_byteValue = SimpleScalarPropertiesResponse.AddMember("byteValue", smithyprelude.Byte)

	SimpleScalarPropertiesResponse_shortValue = SimpleScalarPropertiesResponse.AddMember("shortValue", smithyprelude.Short)

	SimpleScalarPropertiesResponse_integerValue = SimpleScalarPropertiesResponse.AddMember("integerValue", smithyprelude.Integer)

	SimpleScalarPropertiesResponse_longValue = SimpleScalarPropertiesResponse.AddMember("longValue", smithyprelude.Long)

	SimpleScalarPropertiesResponse_floatValue = SimpleScalarPropertiesResponse.AddMember("floatValue", smithyprelude.Float)

	SimpleScalarPropertiesResponse_doubleValue = SimpleScalarPropertiesResponse.AddMember("doubleValue", smithyprelude.Double, &smithytraits.XMLName{Name: "DoubleDribble"})

	TimestampFormatHeadersIO_memberEpochSeconds = TimestampFormatHeadersIO.AddMember("memberEpochSeconds", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "epoch-seconds"},
		&smithytraits.HTTPHeader{Name: "X-memberEpochSeconds"})

	TimestampFormatHeadersIO_memberHttpDate = TimestampFormatHeadersIO.AddMember("memberHttpDate", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "http-date"},
		&smithytraits.HTTPHeader{Name: "X-memberHttpDate"})

	TimestampFormatHeadersIO_memberDateTime = TimestampFormatHeadersIO.AddMember("memberDateTime", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "date-time"},
		&smithytraits.HTTPHeader{Name: "X-memberDateTime"})

	TimestampFormatHeadersIO_defaultFormat = TimestampFormatHeadersIO.AddMember("defaultFormat", smithyprelude.Timestamp, &smithytraits.HTTPHeader{Name: "X-defaultFormat"})

	TimestampFormatHeadersIO_targetEpochSeconds = TimestampFormatHeadersIO.AddMember("targetEpochSeconds", _EpochSeconds, &smithytraits.HTTPHeader{Name: "X-targetEpochSeconds"})

	TimestampFormatHeadersIO_targetHttpDate = TimestampFormatHeadersIO.AddMember("targetHttpDate", _HttpDate, &smithytraits.HTTPHeader{Name: "X-targetHttpDate"})

	TimestampFormatHeadersIO_targetDateTime = TimestampFormatHeadersIO.AddMember("targetDateTime", _DateTime, &smithytraits.HTTPHeader{Name: "X-targetDateTime"})

	XmlAttributesInMiddleRequest_payload = XmlAttributesInMiddleRequest.AddMember("payload", XmlAttributesInMiddlePayloadRequest, &smithytraits.HTTPPayload{})

	XmlAttributesInMiddleResponse_payload = XmlAttributesInMiddleResponse.AddMember("payload", XmlAttributesInMiddlePayloadResponse, &smithytraits.HTTPPayload{})

	XmlAttributesRequest_foo = XmlAttributesRequest.AddMember("foo", smithyprelude.String)

	XmlAttributesRequest_attr = XmlAttributesRequest.AddMember("attr", smithyprelude.String, &smithytraits.XMLName{Name: "test"},
		&smithytraits.XMLAttribute{})

	XmlAttributesOnPayloadRequest_payload = XmlAttributesOnPayloadRequest.AddMember("payload", XmlAttributesPayloadRequest, &smithytraits.HTTPPayload{})

	XmlAttributesOnPayloadResponse_payload = XmlAttributesOnPayloadResponse.AddMember("payload", XmlAttributesPayloadResponse, &smithytraits.HTTPPayload{})

	XmlAttributesResponse_foo = XmlAttributesResponse.AddMember("foo", smithyprelude.String)

	XmlAttributesResponse_attr = XmlAttributesResponse.AddMember("attr", smithyprelude.String, &smithytraits.XMLName{Name: "test"},
		&smithytraits.XMLAttribute{})

	XmlBlobsRequest_data = XmlBlobsRequest.AddMember("data", smithyprelude.Blob)

	XmlBlobsResponse_data = XmlBlobsResponse.AddMember("data", smithyprelude.Blob)

	XmlEmptyBlobsRequest_data = XmlEmptyBlobsRequest.AddMember("data", smithyprelude.Blob)

	XmlEmptyBlobsResponse_data = XmlEmptyBlobsResponse.AddMember("data", smithyprelude.Blob)

	XmlEmptyListsRequest_stringList = XmlEmptyListsRequest.AddMember("stringList", _StringList)

	XmlEmptyListsRequest_stringSet = XmlEmptyListsRequest.AddMember("stringSet", _StringSet)

	XmlEmptyListsRequest_integerList = XmlEmptyListsRequest.AddMember("integerList", _IntegerList)

	XmlEmptyListsRequest_booleanList = XmlEmptyListsRequest.AddMember("booleanList", _BooleanList)

	XmlEmptyListsRequest_timestampList = XmlEmptyListsRequest.AddMember("timestampList", _TimestampList)

	XmlEmptyListsRequest_enumList = XmlEmptyListsRequest.AddMember("enumList", _FooEnumList)

	XmlEmptyListsRequest_intEnumList = XmlEmptyListsRequest.AddMember("intEnumList", _IntegerEnumList)

	XmlEmptyListsRequest_nestedStringList = XmlEmptyListsRequest.AddMember("nestedStringList", _NestedStringList)

	XmlEmptyListsRequest_renamedListMembers = XmlEmptyListsRequest.AddMember("renamedListMembers", _RenamedListMembers, &smithytraits.XMLName{Name: "renamed"})

	XmlEmptyListsRequest_flattenedList = XmlEmptyListsRequest.AddMember("flattenedList", _RenamedListMembers, &smithytraits.XMLFlattened{})

	XmlEmptyListsRequest_flattenedList2 = XmlEmptyListsRequest.AddMember("flattenedList2", _RenamedListMembers, &smithytraits.XMLName{Name: "customName"},
		&smithytraits.XMLFlattened{})

	XmlEmptyListsRequest_flattenedListWithMemberNamespace = XmlEmptyListsRequest.AddMember("flattenedListWithMemberNamespace", _ListWithMemberNamespace, &smithytraits.XMLFlattened{})

	XmlEmptyListsRequest_flattenedListWithNamespace = XmlEmptyListsRequest.AddMember("flattenedListWithNamespace", _ListWithNamespace, &smithytraits.XMLFlattened{})

	XmlEmptyListsRequest_structureList = XmlEmptyListsRequest.AddMember("structureList", _StructureList, &smithytraits.XMLName{Name: "myStructureList"})

	XmlEmptyListsRequest_flattenedStructureList = XmlEmptyListsRequest.AddMember("flattenedStructureList", _StructureList, &smithytraits.XMLFlattened{})

	XmlEmptyListsResponse_stringList = XmlEmptyListsResponse.AddMember("stringList", _StringList)

	XmlEmptyListsResponse_stringSet = XmlEmptyListsResponse.AddMember("stringSet", _StringSet)

	XmlEmptyListsResponse_integerList = XmlEmptyListsResponse.AddMember("integerList", _IntegerList)

	XmlEmptyListsResponse_booleanList = XmlEmptyListsResponse.AddMember("booleanList", _BooleanList)

	XmlEmptyListsResponse_timestampList = XmlEmptyListsResponse.AddMember("timestampList", _TimestampList)

	XmlEmptyListsResponse_enumList = XmlEmptyListsResponse.AddMember("enumList", _FooEnumList)

	XmlEmptyListsResponse_intEnumList = XmlEmptyListsResponse.AddMember("intEnumList", _IntegerEnumList)

	XmlEmptyListsResponse_nestedStringList = XmlEmptyListsResponse.AddMember("nestedStringList", _NestedStringList)

	XmlEmptyListsResponse_renamedListMembers = XmlEmptyListsResponse.AddMember("renamedListMembers", _RenamedListMembers, &smithytraits.XMLName{Name: "renamed"})

	XmlEmptyListsResponse_flattenedList = XmlEmptyListsResponse.AddMember("flattenedList", _RenamedListMembers, &smithytraits.XMLFlattened{})

	XmlEmptyListsResponse_flattenedList2 = XmlEmptyListsResponse.AddMember("flattenedList2", _RenamedListMembers, &smithytraits.XMLName{Name: "customName"},
		&smithytraits.XMLFlattened{})

	XmlEmptyListsResponse_flattenedListWithMemberNamespace = XmlEmptyListsResponse.AddMember("flattenedListWithMemberNamespace", _ListWithMemberNamespace, &smithytraits.XMLFlattened{})

	XmlEmptyListsResponse_flattenedListWithNamespace = XmlEmptyListsResponse.AddMember("flattenedListWithNamespace", _ListWithNamespace, &smithytraits.XMLFlattened{})

	XmlEmptyListsResponse_structureList = XmlEmptyListsResponse.AddMember("structureList", _StructureList, &smithytraits.XMLName{Name: "myStructureList"})

	XmlEmptyListsResponse_flattenedStructureList = XmlEmptyListsResponse.AddMember("flattenedStructureList", _StructureList, &smithytraits.XMLFlattened{})

	XmlEmptyMapsRequest_myMap = XmlEmptyMapsRequest.AddMember("myMap", _XmlMapsInputOutputMap)

	XmlEmptyMapsResponse_myMap = XmlEmptyMapsResponse.AddMember("myMap", _XmlMapsInputOutputMap)

	XmlEmptyStringsRequest_emptyString = XmlEmptyStringsRequest.AddMember("emptyString", smithyprelude.String)

	XmlEmptyStringsResponse_emptyString = XmlEmptyStringsResponse.AddMember("emptyString", smithyprelude.String)

	XmlEnumsRequest_fooEnum1 = XmlEnumsRequest.AddMember("fooEnum1", FooEnum)

	XmlEnumsRequest_fooEnum2 = XmlEnumsRequest.AddMember("fooEnum2", FooEnum)

	XmlEnumsRequest_fooEnum3 = XmlEnumsRequest.AddMember("fooEnum3", FooEnum)

	XmlEnumsRequest_fooEnumList = XmlEnumsRequest.AddMember("fooEnumList", _FooEnumList)

	XmlEnumsRequest_fooEnumSet = XmlEnumsRequest.AddMember("fooEnumSet", _FooEnumSet)

	XmlEnumsRequest_fooEnumMap = XmlEnumsRequest.AddMember("fooEnumMap", _FooEnumMap)

	XmlEnumsResponse_fooEnum1 = XmlEnumsResponse.AddMember("fooEnum1", FooEnum)

	XmlEnumsResponse_fooEnum2 = XmlEnumsResponse.AddMember("fooEnum2", FooEnum)

	XmlEnumsResponse_fooEnum3 = XmlEnumsResponse.AddMember("fooEnum3", FooEnum)

	XmlEnumsResponse_fooEnumList = XmlEnumsResponse.AddMember("fooEnumList", _FooEnumList)

	XmlEnumsResponse_fooEnumSet = XmlEnumsResponse.AddMember("fooEnumSet", _FooEnumSet)

	XmlEnumsResponse_fooEnumMap = XmlEnumsResponse.AddMember("fooEnumMap", _FooEnumMap)

	XmlIntEnumsRequest_intEnum1 = XmlIntEnumsRequest.AddMember("intEnum1", _IntegerEnum)

	XmlIntEnumsRequest_intEnum2 = XmlIntEnumsRequest.AddMember("intEnum2", _IntegerEnum)

	XmlIntEnumsRequest_intEnum3 = XmlIntEnumsRequest.AddMember("intEnum3", _IntegerEnum)

	XmlIntEnumsRequest_intEnumList = XmlIntEnumsRequest.AddMember("intEnumList", _IntegerEnumList)

	XmlIntEnumsRequest_intEnumSet = XmlIntEnumsRequest.AddMember("intEnumSet", _IntegerEnumSet)

	XmlIntEnumsRequest_intEnumMap = XmlIntEnumsRequest.AddMember("intEnumMap", _IntegerEnumMap)

	XmlIntEnumsResponse_intEnum1 = XmlIntEnumsResponse.AddMember("intEnum1", _IntegerEnum)

	XmlIntEnumsResponse_intEnum2 = XmlIntEnumsResponse.AddMember("intEnum2", _IntegerEnum)

	XmlIntEnumsResponse_intEnum3 = XmlIntEnumsResponse.AddMember("intEnum3", _IntegerEnum)

	XmlIntEnumsResponse_intEnumList = XmlIntEnumsResponse.AddMember("intEnumList", _IntegerEnumList)

	XmlIntEnumsResponse_intEnumSet = XmlIntEnumsResponse.AddMember("intEnumSet", _IntegerEnumSet)

	XmlIntEnumsResponse_intEnumMap = XmlIntEnumsResponse.AddMember("intEnumMap", _IntegerEnumMap)

	XmlListsRequest_stringList = XmlListsRequest.AddMember("stringList", _StringList)

	XmlListsRequest_stringSet = XmlListsRequest.AddMember("stringSet", _StringSet)

	XmlListsRequest_integerList = XmlListsRequest.AddMember("integerList", _IntegerList)

	XmlListsRequest_booleanList = XmlListsRequest.AddMember("booleanList", _BooleanList)

	XmlListsRequest_timestampList = XmlListsRequest.AddMember("timestampList", _TimestampList)

	XmlListsRequest_enumList = XmlListsRequest.AddMember("enumList", _FooEnumList)

	XmlListsRequest_intEnumList = XmlListsRequest.AddMember("intEnumList", _IntegerEnumList)

	XmlListsRequest_nestedStringList = XmlListsRequest.AddMember("nestedStringList", _NestedStringList)

	XmlListsRequest_renamedListMembers = XmlListsRequest.AddMember("renamedListMembers", _RenamedListMembers, &smithytraits.XMLName{Name: "renamed"})

	XmlListsRequest_flattenedList = XmlListsRequest.AddMember("flattenedList", _RenamedListMembers, &smithytraits.XMLFlattened{})

	XmlListsRequest_flattenedList2 = XmlListsRequest.AddMember("flattenedList2", _RenamedListMembers, &smithytraits.XMLName{Name: "customName"},
		&smithytraits.XMLFlattened{})

	XmlListsRequest_flattenedListWithMemberNamespace = XmlListsRequest.AddMember("flattenedListWithMemberNamespace", _ListWithMemberNamespace, &smithytraits.XMLFlattened{})

	XmlListsRequest_flattenedListWithNamespace = XmlListsRequest.AddMember("flattenedListWithNamespace", _ListWithNamespace, &smithytraits.XMLFlattened{})

	XmlListsRequest_structureList = XmlListsRequest.AddMember("structureList", _StructureList, &smithytraits.XMLName{Name: "myStructureList"})

	XmlListsRequest_flattenedStructureList = XmlListsRequest.AddMember("flattenedStructureList", _StructureList, &smithytraits.XMLFlattened{})

	XmlListsResponse_stringList = XmlListsResponse.AddMember("stringList", _StringList)

	XmlListsResponse_stringSet = XmlListsResponse.AddMember("stringSet", _StringSet)

	XmlListsResponse_integerList = XmlListsResponse.AddMember("integerList", _IntegerList)

	XmlListsResponse_booleanList = XmlListsResponse.AddMember("booleanList", _BooleanList)

	XmlListsResponse_timestampList = XmlListsResponse.AddMember("timestampList", _TimestampList)

	XmlListsResponse_enumList = XmlListsResponse.AddMember("enumList", _FooEnumList)

	XmlListsResponse_intEnumList = XmlListsResponse.AddMember("intEnumList", _IntegerEnumList)

	XmlListsResponse_nestedStringList = XmlListsResponse.AddMember("nestedStringList", _NestedStringList)

	XmlListsResponse_renamedListMembers = XmlListsResponse.AddMember("renamedListMembers", _RenamedListMembers, &smithytraits.XMLName{Name: "renamed"})

	XmlListsResponse_flattenedList = XmlListsResponse.AddMember("flattenedList", _RenamedListMembers, &smithytraits.XMLFlattened{})

	XmlListsResponse_flattenedList2 = XmlListsResponse.AddMember("flattenedList2", _RenamedListMembers, &smithytraits.XMLName{Name: "customName"},
		&smithytraits.XMLFlattened{})

	XmlListsResponse_flattenedListWithMemberNamespace = XmlListsResponse.AddMember("flattenedListWithMemberNamespace", _ListWithMemberNamespace, &smithytraits.XMLFlattened{})

	XmlListsResponse_flattenedListWithNamespace = XmlListsResponse.AddMember("flattenedListWithNamespace", _ListWithNamespace, &smithytraits.XMLFlattened{})

	XmlListsResponse_structureList = XmlListsResponse.AddMember("structureList", _StructureList, &smithytraits.XMLName{Name: "myStructureList"})

	XmlListsResponse_flattenedStructureList = XmlListsResponse.AddMember("flattenedStructureList", _StructureList, &smithytraits.XMLFlattened{})

	XmlMapsRequest_myMap = XmlMapsRequest.AddMember("myMap", _XmlMapsInputOutputMap)

	XmlMapsResponse_myMap = XmlMapsResponse.AddMember("myMap", _XmlMapsInputOutputMap)

	XmlMapsXmlNameRequest_myMap = XmlMapsXmlNameRequest.AddMember("myMap", _XmlMapsXmlNameInputOutputMap)

	XmlMapsXmlNameResponse_myMap = XmlMapsXmlNameResponse.AddMember("myMap", _XmlMapsXmlNameInputOutputMap)

	XmlMapWithXmlNamespaceRequest_myMap = XmlMapWithXmlNamespaceRequest.AddMember("myMap", _XmlMapWithXmlNamespaceInputOutputMap, &smithytraits.XMLNamespace{URI: "https://the-member.example.com"},
		&smithytraits.XMLName{Name: "KVP"})

	XmlMapWithXmlNamespaceResponse_myMap = XmlMapWithXmlNamespaceResponse.AddMember("myMap", _XmlMapWithXmlNamespaceInputOutputMap, &smithytraits.XMLNamespace{URI: "https://the-member.example.com"},
		&smithytraits.XMLName{Name: "KVP"})

	XmlNamespacesRequest_nested = XmlNamespacesRequest.AddMember("nested", XmlNamespaceNested)

	XmlNamespacesResponse_nested = XmlNamespacesResponse.AddMember("nested", XmlNamespaceNested)

	XmlTimestampsRequest_normal = XmlTimestampsRequest.AddMember("normal", smithyprelude.Timestamp)

	XmlTimestampsRequest_dateTime = XmlTimestampsRequest.AddMember("dateTime", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "date-time"})

	XmlTimestampsRequest_dateTimeOnTarget = XmlTimestampsRequest.AddMember("dateTimeOnTarget", _DateTime)

	XmlTimestampsRequest_epochSeconds = XmlTimestampsRequest.AddMember("epochSeconds", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "epoch-seconds"})

	XmlTimestampsRequest_epochSecondsOnTarget = XmlTimestampsRequest.AddMember("epochSecondsOnTarget", _EpochSeconds)

	XmlTimestampsRequest_httpDate = XmlTimestampsRequest.AddMember("httpDate", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "http-date"})

	XmlTimestampsRequest_httpDateOnTarget = XmlTimestampsRequest.AddMember("httpDateOnTarget", _HttpDate)

	XmlTimestampsResponse_normal = XmlTimestampsResponse.AddMember("normal", smithyprelude.Timestamp)

	XmlTimestampsResponse_dateTime = XmlTimestampsResponse.AddMember("dateTime", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "date-time"})

	XmlTimestampsResponse_dateTimeOnTarget = XmlTimestampsResponse.AddMember("dateTimeOnTarget", _DateTime)

	XmlTimestampsResponse_epochSeconds = XmlTimestampsResponse.AddMember("epochSeconds", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "epoch-seconds"})

	XmlTimestampsResponse_epochSecondsOnTarget = XmlTimestampsResponse.AddMember("epochSecondsOnTarget", _EpochSeconds)

	XmlTimestampsResponse_httpDate = XmlTimestampsResponse.AddMember("httpDate", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "http-date"})

	XmlTimestampsResponse_httpDateOnTarget = XmlTimestampsResponse.AddMember("httpDateOnTarget", _HttpDate)

	XmlUnionsRequest_unionValue = XmlUnionsRequest.AddMember("unionValue", XmlUnionShape)

	XmlUnionsResponse_unionValue = XmlUnionsResponse.AddMember("unionValue", XmlUnionShape)

}
